@@ -16,64 +16,68 @@
 -- drivers referenced in tiny.lst.
 --------------------------------------------------
 
-CPUS["Z80"] = true
+CPUS["COP400"] = true
 CPUS["M6502"] = true
-CPUS["MCS48"] = true
-CPUS["MCS51"] = true
 CPUS["M6800"] = true
 CPUS["M6805"] = true
 CPUS["M6809"] = true
 CPUS["M680X0"] = true
+CPUS["MCS48"] = true
+CPUS["MCS51"] = true
 CPUS["TMS9900"] = true
-CPUS["COP400"] = true
+CPUS["Z80"] = true
 
 --------------------------------------------------
 -- Specify all the sound cores necessary for the
 -- drivers referenced in tiny.lst.
 --------------------------------------------------
 
-SOUNDS["SAMPLES"] = true
+SOUNDS["ASTROCADE"] = true
+SOUNDS["AY8910"] = true
+SOUNDS["CEM3394"] = true
 SOUNDS["DAC"] = true
 SOUNDS["DISCRETE"] = true
-SOUNDS["AY8910"] = true
-SOUNDS["YM2151"] = true
-SOUNDS["ASTROCADE"] = true
-SOUNDS["TMS5220"] = true
-SOUNDS["OKIM6295"] = true
 SOUNDS["HC55516"] = true
-SOUNDS["YM3812"] = true
-SOUNDS["CEM3394"] = true
+SOUNDS["OKIM6295"] = true
+SOUNDS["SAMPLES"] = true
+SOUNDS["TMS5220"] = true
 SOUNDS["VOTRAX"] = true
-SOUNDS["VOLT_REG"] = true
+SOUNDS["YM2151"] = true
+SOUNDS["YM3812"] = true
+
 
 --------------------------------------------------
 -- specify available video cores
 --------------------------------------------------
 
+VIDEOS["MC6845"] = true
+
+
 --------------------------------------------------
 -- specify available machine cores
 --------------------------------------------------
 
 MACHINES["6821PIA"] = true
-MACHINES["ADC0808"] = true
-MACHINES["TTL74148"] = true
-MACHINES["TTL74153"] = true
-MACHINES["TTL74157"] = true
-MACHINES["TTL7474"] = true
-MACHINES["TTL74259"] = true
-MACHINES["RIOT6532"] = true
-MACHINES["PIT8253"] = true
-MACHINES["Z80CTC"] = true
-MACHINES["Z80PIO"] = true
 MACHINES["68681"] = true
+MACHINES["ADC0808"] = true
 MACHINES["BANKDEV"] = true
 MACHINES["GEN_LATCH"] = true
 MACHINES["INPUT_MERGER"] = true
-MACHINES["OUTPUT_LATCH"] = true
-MACHINES["TICKET"] = true
-MACHINES["WATCHDOG"] = true
-MACHINES["Z80DAISY"] = true
 MACHINES["NETLIST"] = true
+MACHINES["OUTPUT_LATCH"] = true
+MACHINES["PIT8253"] = true
+MACHINES["RIOT6532"] = true
+MACHINES["TICKET"] = true
+MACHINES["TIMEKPR"] = true
+MACHINES["TTL74148"] = true
+MACHINES["TTL74153"] = true
+MACHINES["TTL74157"] = true
+MACHINES["TTL74259"] = true
+MACHINES["TTL7474"] = true
+MACHINES["WATCHDOG"] = true
+MACHINES["Z80CTC"] = true
+MACHINES["Z80DAISY"] = true
+MACHINES["Z80PIO"] = true
 
 
 --------------------------------------------------
@@ -82,6 +86,7 @@ MACHINES["NETLIST"] = true
 
 BUSES["CENTRONICS"] = true
 
+
 --------------------------------------------------
 -- This is the list of files that are necessary
 -- for building all of the drivers referenced
@@ -108,15 +113,15 @@ function createProjects_mame_tiny(_target, _subtarget)
 	}
 
 files{
-	MAME_DIR .. "src/mame/audio/nl_carpolo.h",
 	MAME_DIR .. "src/mame/audio/nl_carpolo.cpp",
+	MAME_DIR .. "src/mame/audio/nl_carpolo.h",
 	MAME_DIR .. "src/mame/drivers/carpolo.cpp",
 	MAME_DIR .. "src/mame/includes/carpolo.h",
 	MAME_DIR .. "src/mame/machine/carpolo.cpp",
 	MAME_DIR .. "src/mame/video/carpolo.cpp",
+	MAME_DIR .. "src/mame/audio/circus.cpp",
 	MAME_DIR .. "src/mame/drivers/circus.cpp",
 	MAME_DIR .. "src/mame/includes/circus.h",
-	MAME_DIR .. "src/mame/audio/circus.cpp",
 	MAME_DIR .. "src/mame/video/circus.cpp",
 	MAME_DIR .. "src/mame/drivers/exidy.cpp",
 	MAME_DIR .. "src/mame/includes/exidy.h",
@@ -139,7 +144,6 @@ files{
 	MAME_DIR .. "src/mame/drivers/victory.cpp",
 	MAME_DIR .. "src/mame/includes/victory.h",
 	MAME_DIR .. "src/mame/video/victory.cpp",
-	MAME_DIR .. "src/mame/audio/targ.cpp",
 	MAME_DIR .. "src/mame/drivers/astrocde.cpp",
 	MAME_DIR .. "src/mame/includes/astrocde.h",
 	MAME_DIR .. "src/mame/video/astrocde.cpp",
@@ -147,11 +151,13 @@ files{
 	MAME_DIR .. "src/mame/includes/gridlee.h",
 	MAME_DIR .. "src/mame/audio/gridlee.cpp",
 	MAME_DIR .. "src/mame/video/gridlee.cpp",
+	MAME_DIR .. "src/mame/audio/s11c_bg.cpp",
+	MAME_DIR .. "src/mame/audio/s11c_bg.h",
+	MAME_DIR .. "src/mame/audio/williams.cpp",
+	MAME_DIR .. "src/mame/audio/williams.h",
 	MAME_DIR .. "src/mame/drivers/williams.cpp",
 	MAME_DIR .. "src/mame/includes/williams.h",
 	MAME_DIR .. "src/mame/machine/williams.cpp",
-	MAME_DIR .. "src/mame/audio/williams.cpp",
-	MAME_DIR .. "src/mame/audio/williams.h",
 	MAME_DIR .. "src/mame/video/williams.cpp",
 	MAME_DIR .. "src/mame/drivers/gaelco.cpp",
 	MAME_DIR .. "src/mame/includes/gaelco.h",
@@ -167,6 +173,7 @@ files{
 	MAME_DIR .. "src/mame/machine/gaelco_ds5002fp.h",
 	MAME_DIR .. "src/mame/drivers/looping.cpp",
 	MAME_DIR .. "src/mame/drivers/supertnk.cpp",
+	MAME_DIR .. "src/mame/drivers/goldnpkr.cpp",
 }
 end
 
