@@ -30,7 +30,7 @@ void o2_ktaa_device::device_start()
 
 void o2_ktaa_device::cart_init()
 {
-	u32 size = m_rom.bytes();
+	u32 size = m_rom_size;
 	if (size != 0xc00 && size != 0xc00*2 && size != 0xc00*4)
 		fatalerror("o2_ktaa_device: ROM size must be multiple of 3KB\n");
 
