@@ -20,9 +20,9 @@ public:
 	virtual void late_bank_setup() override;
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override;
 
 protected:
 	sega8_rom_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock);
@@ -48,9 +48,9 @@ public:
 	sega8_othello_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override { }
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override { }
 };
 
 
@@ -63,9 +63,9 @@ public:
 	sega8_castle_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override { }
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override { }
 };
 
 
@@ -78,13 +78,13 @@ public:
 	sega8_basic_l3_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override { }
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override { }
 
 	// has internal RAM which overwrites the system one!
-	virtual DECLARE_READ8_MEMBER(read_ram) override;
-	virtual DECLARE_WRITE8_MEMBER(write_ram) override;
+	virtual uint8_t read_ram(offs_t offset) override;
+	virtual void write_ram(offs_t offset, uint8_t data) override;
 };
 
 
@@ -97,13 +97,13 @@ public:
 	sega8_music_editor_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override { }
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override { }
 
 	// has internal RAM which overwrites the system one!
-	virtual DECLARE_READ8_MEMBER(read_ram) override;
-	virtual DECLARE_WRITE8_MEMBER(write_ram) override;
+	virtual uint8_t read_ram(offs_t offset) override;
+	virtual void write_ram(offs_t offset, uint8_t data) override;
 };
 
 
@@ -123,9 +123,9 @@ public:
 	required_ioport m_tvdraw_pen;
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override { }
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override { }
 
 protected:
 	virtual void device_start() override;
@@ -144,13 +144,13 @@ public:
 	sega8_dahjee_typea_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override { }
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override { }
 
 	// has internal RAM which overwrites the system one!
-	virtual DECLARE_READ8_MEMBER(read_ram) override;
-	virtual DECLARE_WRITE8_MEMBER(write_ram) override;
+	virtual uint8_t read_ram(offs_t offset) override;
+	virtual void write_ram(offs_t offset, uint8_t data) override;
 };
 
 
@@ -163,13 +163,13 @@ public:
 	sega8_dahjee_typeb_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override { }
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override { }
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override { }
+	virtual void write_mapper(offs_t offset, uint8_t data) override { }
 
 	// has internal RAM which overwrites the system one!
-	virtual DECLARE_READ8_MEMBER(read_ram) override;
-	virtual DECLARE_WRITE8_MEMBER(write_ram) override;
+	virtual uint8_t read_ram(offs_t offset) override;
+	virtual void write_ram(offs_t offset, uint8_t data) override;
 };
 
 
@@ -187,9 +187,9 @@ public:
 	virtual void late_bank_setup() override;
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override;
 
 protected:
 	virtual void device_start() override;
@@ -218,8 +218,8 @@ public:
 	virtual void late_bank_setup() override;
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
 	// no mapper write for this!
 
 protected:
@@ -242,8 +242,8 @@ public:
 	sega8_4pak_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
 
 protected:
 	// device-level overrides
@@ -267,8 +267,8 @@ public:
 	virtual void late_bank_setup() override;
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
 	// no mapper write for this!
 
 protected:
@@ -308,9 +308,9 @@ public:
 	virtual void late_bank_setup() override;
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override;
 
 protected:
 	// device-level overrides
@@ -331,9 +331,9 @@ public:
 	virtual void late_bank_setup() override;
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override {}
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override {}
+	virtual void write_mapper(offs_t offset, uint8_t data) override;
 
 protected:
 	// device-level overrides
@@ -354,8 +354,8 @@ public:
 	virtual void late_bank_setup() override;
 
 	// reading and writing
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override {}
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override {}
 };
 
 
@@ -368,7 +368,7 @@ public:
 	sega8_korean_nb_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override {}
+	virtual void write_mapper(offs_t offset, uint8_t data) override {}
 };
 
 
@@ -381,11 +381,11 @@ public:
 	sega8_seojin_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_mapper) override;
-	virtual DECLARE_READ8_MEMBER(read_ram) override;
-	virtual DECLARE_WRITE8_MEMBER(write_ram) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_mapper(offs_t offset, uint8_t data) override;
+	virtual uint8_t read_ram(offs_t offset) override;
+	virtual void write_ram(offs_t offset, uint8_t data) override;
 
 protected:
 	// device-level overrides
@@ -406,13 +406,13 @@ public:
 	sega8_multicart_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_io) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_io(offs_t offset, uint8_t data) override;
 
 	// has internal RAM which overwrites the system one!
-	virtual DECLARE_READ8_MEMBER(read_ram) override;
-	virtual DECLARE_WRITE8_MEMBER(write_ram) override;
+	virtual uint8_t read_ram(offs_t offset) override;
+	virtual void write_ram(offs_t offset, uint8_t data) override;
 
 protected:
 	// device-level overrides
@@ -433,13 +433,13 @@ public:
 	sega8_megacart_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// reading and writing
-	virtual DECLARE_READ8_MEMBER(read_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_cart) override;
-	virtual DECLARE_WRITE8_MEMBER(write_io) override;
+	virtual uint8_t read_cart(offs_t offset) override;
+	virtual void write_cart(offs_t offset, uint8_t data) override;
+	virtual void write_io(offs_t offset, uint8_t data) override;
 
 	// has internal RAM which overwrites the system one!
-	virtual DECLARE_READ8_MEMBER(read_ram) override;
-	virtual DECLARE_WRITE8_MEMBER(write_ram) override;
+	virtual uint8_t read_ram(offs_t offset) override;
+	virtual void write_ram(offs_t offset, uint8_t data) override;
 
 protected:
 	// device-level overrides
