@@ -60,7 +60,7 @@ DEFINE_DEVICE_TYPE(SG1000_CARD_SLOT,    sg1000_card_slot_device,    "sg1000_card
 //-------------------------------------------------
 
 device_sega8_cart_interface::device_sega8_cart_interface(const machine_config &mconfig, device_t &device)
-	: device_slot_card_interface(mconfig, device)
+	: device_interface(device, "sega8cart")
 	, m_rom(nullptr)
 	, m_rom_size(0)
 	, m_rom_page_count(0)
@@ -120,7 +120,7 @@ void device_sega8_cart_interface::ram_alloc(uint32_t size)
 sega8_cart_slot_device::sega8_cart_slot_device(const machine_config &mconfig, device_type type, const char *tag, device_t *owner, uint32_t clock, bool is_card)
 	: device_t(mconfig, type, tag, owner, clock)
 	, device_image_interface(mconfig, *this)
-	, device_slot_interface(mconfig, *this)
+	, device_single_card_slot_interface<device_sega8_cart_interface>(mconfig, *this)
 	, m_type(SEGA8_BASE_ROM)
 	, m_is_card(is_card)
 	, m_cart(nullptr)
@@ -198,7 +198,7 @@ sega8_cart_slot_device::~sega8_cart_slot_device()
 
 void sega8_cart_slot_device::device_start()
 {
-	m_cart = dynamic_cast<device_sega8_cart_interface *>(get_card_device());
+	m_cart = get_card_device();
 }
 
 //-------------------------------------------------
@@ -685,26 +685,26 @@ std::string sega8_cart_slot_device::get_default_card_software(get_default_card_s
  read
  -------------------------------------------------*/
 
-READ8_MEMBER(sega8_cart_slot_device::read_cart)
+uint8_t sega8_cart_slot_device::read_cart(offs_t offset)
 {
 	if (m_cart)
-		return m_cart->read_cart(space, offset);
+		return m_cart->read_cart(offset);
 	else
 		return 0xff;
 }
 
-READ8_MEMBER(sega8_cart_slot_device::read_ram)
+uint8_t sega8_cart_slot_device::read_ram(offs_t offset)
 {
 	if (m_cart)
-		return m_cart->read_ram(space, offset);
+		return m_cart->read_ram(offset);
 	else
 		return 0xff;
 }
 
-READ8_MEMBER(sega8_cart_slot_device::read_io)
+uint8_t sega8_cart_slot_device::read_io(offs_t offset)
 {
 	if (m_cart)
-		return m_cart->read_io(space, offset);
+		return m_cart->read_io(offset);
 	else
 		return 0xff;
 }
@@ -714,28 +714,28 @@ READ8_MEMBER(sega8_cart_slot_device::read_io)
  write
  -------------------------------------------------*/
 
-WRITE8_MEMBER(sega8_cart_slot_device::write_mapper)
+void sega8_cart_slot_device::write_mapper(offs_t offset, uint8_t data)
 {
 	if (m_cart)
-		m_cart->write_mapper(space, offset, data);
+		m_cart->write_mapper(offset, data);
 }
 
-WRITE8_MEMBER(sega8_cart_slot_device::write_cart)
+void sega8_cart_slot_device::write_cart(offs_t offset, uint8_t data)
 {
 	if (m_cart)
-		m_cart->write_cart(space, offset, data);
+		m_cart->write_cart(offset, data);
 }
 
-WRITE8_MEMBER(sega8_cart_slot_device::write_ram)
+void sega8_cart_slot_device::write_ram(offs_t offset, uint8_t data)
 {
 	if (m_cart)
-		m_cart->write_ram(space, offset, data);
+		m_cart->write_ram(offset, data);
 }
 
-WRITE8_MEMBER(sega8_cart_slot_device::write_io)
+void sega8_cart_slot_device::write_io(offs_t offset, uint8_t data)
 {
 	if (m_cart)
-		m_cart->write_io(space, offset, data);
+		m_cart->write_io(offset, data);
 }
 
 
