@@ -199,6 +199,7 @@ protected:
 	uint8_t       m_dbbo;               /* 8-bit output data buffer (UPI-41 only) */
 
 	bool          m_irq_state;          /* true if the IRQ line is active */
+	bool          m_irq_polled;         /* true if last instruction was JNI (and not taken) */
 	bool          m_irq_in_progress;    /* true if an IRQ is in progress */
 	bool          m_timer_overflow;     /* true on a timer overflow; cleared by taking interrupt */
 	bool          m_timer_flag;         /* true on a timer overflow; cleared on JTF */
@@ -257,7 +258,7 @@ protected:
 	void execute_addc(uint8_t dat);
 	void execute_jmp(uint16_t address);
 	void execute_call(uint16_t address);
-	void execute_jcc(uint8_t result);
+	void execute_jcc(bool result);
 	uint8_t p2_mask();
 	void expander_operation(expander_op operation, uint8_t port);
 	void check_irqs();
