@@ -74,7 +74,7 @@ const options_entry emu_options::s_option_entries[] =
 	{ OPTION_WAVWRITE,                                   nullptr,     OPTION_STRING,     "optional filename to write a WAV file of the current session" },
 	{ OPTION_SNAPNAME,                                   "%g/%i",     OPTION_STRING,     "override of the default snapshot/movie naming; %g == gamename, %i == index" },
 	{ OPTION_SNAPSIZE,                                   "auto",      OPTION_STRING,     "specify snapshot/movie resolution (<width>x<height>) or 'auto' to use minimal size " },
-	{ OPTION_SNAPVIEW,                                   "internal",  OPTION_STRING,     "specify snapshot/movie view or 'internal' to use internal pixel-aspect views" },
+	{ OPTION_SNAPVIEW,                                   "auto",      OPTION_STRING,     "snapshot/movie view - 'auto' for default, or 'native' for per-screen pixel-aspect views" },
 	{ OPTION_SNAPBILINEAR,                               "1",         OPTION_BOOLEAN,    "specify if the snapshot/movie should have bilinear filtering applied" },
 	{ OPTION_STATENAME,                                  "%g",        OPTION_STRING,     "override of the default state subfolder naming; %g == gamename" },
 	{ OPTION_BURNIN,                                     "0",         OPTION_BOOLEAN,    "create burn-in snapshots for each screen" },
@@ -567,7 +567,7 @@ bool emu_options::add_and_remove_slot_options()
 		// create the configuration
 		machine_config config(*m_system, *this);
 
-		for (const device_slot_interface &slot : slot_interface_iterator(config.root_device()))
+		for (const device_slot_interface &slot : slot_interface_enumerator(config.root_device()))
 		{
 			// come up with the canonical name of the slot
 			const char *slot_option_name = slot.slot_name();
@@ -664,7 +664,7 @@ bool emu_options::add_and_remove_image_options()
 		machine_config config(*m_system, *this);
 
 		// iterate through all image devices
-		for (device_image_interface &image : image_interface_iterator(config.root_device()))
+		for (device_image_interface &image : image_interface_enumerator(config.root_device()))
 		{
 			const std::string &canonical_name(image.canonical_instance_name());
 
@@ -745,7 +745,7 @@ void emu_options::reevaluate_default_card_software()
 		found = false;
 
 		// iterate through all slot devices
-		for (device_slot_interface &slot : slot_interface_iterator(config.root_device()))
+		for (device_slot_interface &slot : slot_interface_enumerator(config.root_device()))
 		{
 			// retrieve info about the device instance
 			auto &slot_opt(slot_option(slot.slot_name()));
@@ -883,9 +883,9 @@ emu_options::software_options emu_options::evaluate_initial_softlist_options(con
 
 		// and set up a configuration
 		machine_config config(*m_system, *this);
-		software_list_device_iterator iter(config.root_device());
+		software_list_device_enumerator iter(config.root_device());
 		if (iter.count() == 0)
-			throw emu_fatalerror(EMU_ERR_FATALERROR, "Error: unknown option: %s\n", software_identifier.c_str());
+			throw emu_fatalerror(EMU_ERR_FATALERROR, "Error: unknown option: %s\n", software_identifier);
 
 		// and finally set up the stack
 		std::stack<std::string> software_identifier_stack;
