@@ -140,7 +140,7 @@ running_machine::running_machine(const machine_config &_config, machine_manager
 	m_dummy_space.config_complete();
 
 	// set the machine on all devices
-	device_iterator iter(root_device());
+	device_enumerator iter(root_device());
 	for (device_t &device : iter)
 		device.set_machine(*this);
 
@@ -199,7 +199,7 @@ void running_machine::start()
 	m_soft_reset_timer = m_scheduler.timer_alloc(timer_expired_delegate(FUNC(running_machine::soft_reset), this));
 
 	// initialize UI input
-	m_ui_input = make_unique_clear<ui_input_manager>(*this);
+	m_ui_input = std::make_unique<ui_input_manager>(*this);
 
 	// init the osd layer
 	m_manager.osd().init(*this);
@@ -222,7 +222,7 @@ void running_machine::start()
 	m_sound = std::make_unique<sound_manager>(*this);
 
 	// resolve objects that can be used by memory maps
-	for (device_t &device : device_iterator(root_device()))
+	for (device_t &device : device_enumerator(root_device()))
 		device.resolve_pre_map();
 
 	// configure the address spaces, load ROMs (which needs
@@ -230,7 +230,7 @@ void running_machine::start()
 	// needs rom bases), and finally initialize CPUs (which needs
 	// complete address spaces).  These operations must proceed in this
 	// order
-	m_rom_load = make_unique_clear<rom_load_manager>(*this);
+	m_rom_load = std::make_unique<rom_load_manager>(*this);
 	m_memory.initialize();
 
 	// save the random seed or save states might be broken in drivers that use the rand() method
@@ -239,7 +239,7 @@ void running_machine::start()
 	// initialize image devices
 	m_image = std::make_unique<image_manager>(*this);
 	m_tilemap = std::make_unique<tilemap_manager>(*this);
-	m_crosshair = make_unique_clear<crosshair_manager>(*this);
+	m_crosshair = std::make_unique<crosshair_manager>(*this);
 	m_network = std::make_unique<network_manager>(*this);
 
 	// initialize the debugger
@@ -252,7 +252,7 @@ void running_machine::start()
 	manager().create_custom(*this);
 
 	// resolve objects that are created by memory maps
-	for (device_t &device : device_iterator(root_device()))
+	for (device_t &device : device_enumerator(root_device()))
 		device.resolve_post_map();
 
 	// register callbacks for the devices, then start them
@@ -551,7 +551,7 @@ std::string running_machine::get_statename(const char *option) const
 			//printf("check template: %s\n", devname_str.c_str());
 
 			// verify that there is such a device for this system
-			for (device_image_interface &image : image_interface_iterator(root_device()))
+			for (device_image_interface &image : image_interface_enumerator(root_device()))
 			{
 				// get the device name
 				std::string tempdevname(image.brief_instance_name());
@@ -878,7 +878,7 @@ void running_machine::current_datetime(system_time &systime)
 
 void running_machine::set_rtc_datetime(const system_time &systime)
 {
-	for (device_rtc_interface &rtc : rtc_interface_iterator(root_device()))
+	for (device_rtc_interface &rtc : rtc_interface_enumerator(root_device()))
 		if (rtc.has_battery())
 			rtc.set_current_time(systime);
 }
@@ -984,10 +984,14 @@ void running_machine::handle_saveload()
 					file.remove_on_close();
 			}
 			else if (openflags == OPEN_FLAG_READ && filerr == osd_file::error::NOT_FOUND)
+			{
 				// attempt to load a non-existent savestate, report empty slot
 				popmessage("Error: No savestate file to load.", opname);
+			}
 			else
+			{
 				popmessage("Error: Failed to open file for %s operation.", opname);
+			}
 		}
 	}
 
@@ -1047,7 +1051,7 @@ void running_machine::start_all_devices()
 	{
 		// iterate over all devices
 		int failed_starts = 0;
-		for (device_t &device : device_iterator(root_device()))
+		for (device_t &device : device_enumerator(root_device()))
 			if (!device.started())
 			{
 				// attempt to start the device, catching any expected exceptions
@@ -1104,7 +1108,7 @@ void running_machine::stop_all_devices()
 		debugger().cpu().comment_save();
 
 	// iterate over devices and stop them
-	for (device_t &device : device_iterator(root_device()))
+	for (device_t &device : device_enumerator(root_device()))
 		device.stop();
 }
 
@@ -1116,7 +1120,7 @@ void running_machine::stop_all_devices()
 
 void running_machine::presave_all_devices()
 {
-	for (device_t &device : device_iterator(root_device()))
+	for (device_t &device : device_enumerator(root_device()))
 		device.pre_save();
 }
 
@@ -1128,7 +1132,7 @@ void running_machine::presave_all_devices()
 
 void running_machine::postload_all_devices()
 {
-	for (device_t &device : device_iterator(root_device()))
+	for (device_t &device : device_enumerator(root_device()))
 		device.post_load();
 }
 
@@ -1181,7 +1185,7 @@ std::string running_machine::nvram_filename(device_t &device) const
 
 void running_machine::nvram_load()
 {
-	for (device_nvram_interface &nvram : nvram_interface_iterator(root_device()))
+	for (device_nvram_interface &nvram : nvram_interface_enumerator(root_device()))
 	{
 		emu_file file(options().nvram_directory(), OPEN_FLAG_READ);
 		if (file.open(nvram_filename(nvram.device())) == osd_file::error::NONE)
@@ -1201,7 +1205,7 @@ void running_machine::nvram_load()
 
 void running_machine::nvram_save()
 {
-	for (device_nvram_interface &nvram : nvram_interface_iterator(root_device()))
+	for (device_nvram_interface &nvram : nvram_interface_enumerator(root_device()))
 	{
 		if (nvram.nvram_can_save())
 		{
@@ -1269,7 +1273,7 @@ void running_machine::export_http_api()
 			writer.Key("devices");
 			writer.StartArray();
 
-			device_iterator iter(this->root_device());
+			device_enumerator iter(this->root_device());
 			for (device_t &device : iter)
 				writer.String(device.tag());
 
