@@ -163,7 +163,7 @@ private:
 DECLARE_DEVICE_TYPE(SOFTWARE_LIST, software_list_device)
 
 // device type iterator
-typedef device_type_iterator<software_list_device> software_list_device_iterator;
+typedef device_type_enumerator<software_list_device> software_list_device_enumerator;
 
 
 #endif // MAME_EMU_SOFTLIST_DEV_H
