@@ -14,6 +14,7 @@
 #include "emuopts.h"
 #include "romload.h"
 #include "video/rgbutil.h"
+#include "unicode.h"
 
 #include <cctype>
 #include <type_traits>
@@ -82,7 +83,7 @@ void validity_checker::validate_tag(const char *tag)
 
 	// scan for invalid characters
 	static char const *const validchars = "abcdefghijklmnopqrstuvwxyz0123456789_.:^$";
-	for (const char *p = tag; *p != 0; p++)
+	for (char const *p = tag; *p; ++p)
 	{
 		// only lower-case permitted
 		if (*p != tolower(u8(*p)))
@@ -95,7 +96,7 @@ void validity_checker::validate_tag(const char *tag)
 			osd_printf_error("Tag '%s' contains spaces\n", tag);
 			break;
 		}
-		if (strchr(validchars, *p) == nullptr)
+		if (!strchr(validchars, *p))
 		{
 			osd_printf_error("Tag '%s' contains invalid character '%c'\n",  tag, *p);
 			break;
@@ -128,16 +129,16 @@ void validity_checker::validate_tag(const char *tag)
 //  validity_checker - constructor
 //-------------------------------------------------
 
-validity_checker::validity_checker(emu_options &options)
+validity_checker::validity_checker(emu_options &options, bool quick)
 	: m_drivlist(options)
 	, m_errors(0)
 	, m_warnings(0)
 	, m_print_verbose(options.verbose())
 	, m_current_driver(nullptr)
-	, m_current_config(nullptr)
 	, m_current_device(nullptr)
 	, m_current_ioport(nullptr)
-	, m_validate_all(false)
+	, m_checking_card(false)
+	, m_quick(quick)
 {
 	// pre-populate the defstr map with all the default strings
 	for (int strnum = 1; strnum < INPUT_STRING_COUNT; strnum++)
@@ -261,6 +262,7 @@ void validity_checker::validate_begin()
 	m_roms_map.clear();
 	m_defstr_map.clear();
 	m_region_map.clear();
+	m_ioport_set.clear();
 
 	// reset internal state
 	m_errors = 0;
@@ -293,10 +295,11 @@ void validity_checker::validate_one(const game_driver &driver)
 
 	// set the current driver
 	m_current_driver = &driver;
-	m_current_config = nullptr;
 	m_current_device = nullptr;
 	m_current_ioport = nullptr;
 	m_region_map.clear();
+	m_ioport_set.clear();
+	m_checking_card = false;
 
 	// reset error/warning state
 	int start_errors = m_errors;
@@ -305,18 +308,16 @@ void validity_checker::validate_one(const game_driver &driver)
 	m_warning_text.clear();
 	m_verbose_text.clear();
 
-	// wrap in try/except to catch fatalerrors
+	// wrap in try/catch to catch fatalerrors
 	try
 	{
 		machine_config config(driver, m_blank_options);
-		m_current_config = &config;
-		validate_driver();
-		validate_roms(m_current_config->root_device());
-		validate_inputs();
-		validate_devices();
-		m_current_config = nullptr;
+		validate_driver(config.root_device());
+		validate_roms(config.root_device());
+		validate_inputs(config.root_device());
+		validate_devices(config);
 	}
-	catch (emu_fatalerror &err)
+	catch (emu_fatalerror const &err)
 	{
 		osd_printf_error("Fatal error %s", err.what());
 	}
@@ -338,9 +339,11 @@ void validity_checker::validate_one(const game_driver &driver)
 
 	// reset the driver/device
 	m_current_driver = nullptr;
-	m_current_config = nullptr;
 	m_current_device = nullptr;
 	m_current_ioport = nullptr;
+	m_region_map.clear();
+	m_ioport_set.clear();
+	m_checking_card = false;
 }
 
 
@@ -1454,7 +1457,7 @@ void validity_checker::validate_rgb()
 //  information
 //-------------------------------------------------
 
-void validity_checker::validate_driver()
+void validity_checker::validate_driver(device_t &root)
 {
 	// check for duplicate names
 	if (!m_names_map.insert(std::make_pair(m_current_driver->name, m_current_driver)).second)
@@ -1537,7 +1540,7 @@ void validity_checker::validate_driver()
 	device_t::feature_type const imperfect(m_current_driver->type.imperfect_features());
 	if (!(m_current_driver->flags & (machine_flags::IS_BIOS_ROOT | machine_flags::NO_SOUND_HW)) && !(unemulated & device_t::feature::SOUND))
 	{
-		sound_interface_iterator iter(m_current_config->root_device());
+		sound_interface_enumerator iter(root);
 		if (!iter.first())
 			osd_printf_error("Driver is missing MACHINE_NO_SOUND or MACHINE_NO_SOUND_HW flag\n");
 	}
@@ -1561,7 +1564,7 @@ void validity_checker::validate_driver()
 void validity_checker::validate_roms(device_t &root)
 {
 	// iterate, starting with the driver's ROMs and continuing with device ROMs
-	for (device_t &device : device_iterator(root))
+	for (device_t &device : device_enumerator(root))
 	{
 		// track the current device
 		m_current_device = &device;
@@ -1852,11 +1855,10 @@ void validity_checker::validate_dip_settings(ioport_field &field)
 //  stored within an ioport field or setting
 //-------------------------------------------------
 
-void validity_checker::validate_condition(ioport_condition &condition, device_t &device, std::unordered_set<std::string> &port_map)
+void validity_checker::validate_condition(ioport_condition &condition, device_t &device)
 {
-	// resolve the tag
-	// then find a matching port
-	if (port_map.find(device.subtag(condition.tag())) == port_map.end())
+	// resolve the tag, then find a matching port
+	if (m_ioport_set.find(device.subtag(condition.tag())) == m_ioport_set.end())
 		osd_printf_error("Condition referencing non-existent ioport tag '%s'\n", condition.tag());
 }
 
@@ -1865,12 +1867,10 @@ void validity_checker::validate_condition(ioport_condition &condition, device_t
 //  validate_inputs - validate input configuration
 //-------------------------------------------------
 
-void validity_checker::validate_inputs()
+void validity_checker::validate_inputs(device_t &root)
 {
-	std::unordered_set<std::string> port_map;
-
 	// iterate over devices
-	for (device_t &device : device_iterator(m_current_config->root_device()))
+	for (device_t &device : device_enumerator(root))
 	{
 		// see if this device has ports; if not continue
 		if (device.input_ports() == nullptr)
@@ -1890,7 +1890,7 @@ void validity_checker::validate_inputs()
 
 		// do a first pass over ports to add their names and find duplicates
 		for (auto &port : portlist)
-			if (!port_map.insert(port.second->tag()).second)
+			if (!m_ioport_set.insert(port.second->tag()).second)
 				osd_printf_error("Multiple I/O ports with the same tag '%s' defined\n", port.second->tag());
 
 		// iterate over ports
@@ -1898,6 +1898,22 @@ void validity_checker::validate_inputs()
 		{
 			m_current_ioport = port.second->tag();
 
+			// scan for invalid characters
+			static char const *const validchars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_.:^$";
+			for (char const *p = m_current_ioport; *p; ++p)
+			{
+				if (*p == ' ')
+				{
+					osd_printf_error("Tag '%s' contains spaces\n", m_current_ioport);
+					break;
+				}
+				if (!strchr(validchars, *p))
+				{
+					osd_printf_error("Tag '%s' contains invalid character '%c'\n",  m_current_ioport, *p);
+					break;
+				}
+			}
+
 			// iterate through the fields on this port
 			for (ioport_field &field : port.second->fields())
 			{
@@ -1953,12 +1969,12 @@ void validity_checker::validate_inputs()
 
 				// verify conditions on the field
 				if (!field.condition().none())
-					validate_condition(field.condition(), device, port_map);
+					validate_condition(field.condition(), device);
 
 				// verify conditions on the settings
 				for (ioport_setting &setting : field.settings())
 					if (!setting.condition().none())
-						validate_condition(setting.condition(), device, port_map);
+						validate_condition(setting.condition(), device);
 
 				// verify natural keyboard codes
 				for (int which = 0; which < 1 << (UCHAR_SHIFT_END - UCHAR_SHIFT_BEGIN + 1); which++)
@@ -1969,9 +1985,9 @@ void validity_checker::validate_inputs()
 						if (!uchar_isvalid(code))
 						{
 							osd_printf_error("Field '%s' has non-character U+%04X in PORT_CHAR(%d)\n",
-								name,
-								(unsigned)code,
-								(int)code);
+									name,
+									(unsigned)code,
+									(int)code);
 						}
 					}
 				}
@@ -1992,17 +2008,17 @@ void validity_checker::validate_inputs()
 //  checks
 //-------------------------------------------------
 
-void validity_checker::validate_devices()
+void validity_checker::validate_devices(machine_config &config)
 {
 	std::unordered_set<std::string> device_map;
 
-	for (device_t &device : device_iterator(m_current_config->root_device()))
+	for (device_t &device : device_enumerator(config.root_device()))
 	{
 		// track the current device
 		m_current_device = &device;
 
 		// validate auto-finders
-		device.findit(true);
+		device.findit(this);
 
 		// validate the device tag
 		validate_tag(device.basetag());
@@ -2028,10 +2044,11 @@ void validity_checker::validate_devices()
 				if (slot->default_option() != nullptr && option.first == slot->default_option())
 					continue;
 
+				m_checking_card = true;
 				device_t *card;
 				{
-					machine_config::token const tok(m_current_config->begin_configuration(slot->device()));
-					card = m_current_config->device_add(option.second->name(), option.second->devtype(), option.second->clock());
+					machine_config::token const tok(config.begin_configuration(slot->device()));
+					card = config.device_add(option.second->name(), option.second->devtype(), option.second->clock());
 
 					const char *const def_bios = option.second->default_bios();
 					if (def_bios)
@@ -2041,7 +2058,7 @@ void validity_checker::validate_devices()
 						additions(card);
 				}
 
-				for (device_slot_interface &subslot : slot_interface_iterator(*card))
+				for (device_slot_interface &subslot : slot_interface_enumerator(*card))
 				{
 					if (subslot.fixed())
 					{
@@ -2049,8 +2066,8 @@ void validity_checker::validate_devices()
 						device_slot_interface::slot_option const *suboption = subslot.option(subslot.default_option());
 						if (suboption)
 						{
-							machine_config::token const tok(m_current_config->begin_configuration(subslot.device()));
-							device_t *const sub_card = m_current_config->device_add(suboption->name(), suboption->devtype(), suboption->clock());
+							machine_config::token const tok(config.begin_configuration(subslot.device()));
+							device_t *const sub_card = config.device_add(suboption->name(), suboption->devtype(), suboption->clock());
 							const char *const sub_bios = suboption->default_bios();
 							if (sub_bios)
 								sub_card->set_default_bios_tag(sub_bios);
@@ -2061,20 +2078,21 @@ void validity_checker::validate_devices()
 					}
 				}
 
-				for (device_t &card_dev : device_iterator(*card))
+				for (device_t &card_dev : device_enumerator(*card))
 					card_dev.config_complete();
 				validate_roms(*card);
 
-				for (device_t &card_dev : device_iterator(*card))
+				for (device_t &card_dev : device_enumerator(*card))
 				{
 					m_current_device = &card_dev;
-					card_dev.findit(true);
+					card_dev.findit(this);
 					card_dev.validity_check(*this);
 					m_current_device = nullptr;
 				}
 
-				machine_config::token const tok(m_current_config->begin_configuration(slot->device()));
-				m_current_config->device_remove(option.second->name());
+				machine_config::token const tok(config.begin_configuration(slot->device()));
+				config.device_remove(option.second->name());
+				m_checking_card = false;
 			}
 		}
 	}
@@ -2100,7 +2118,7 @@ void validity_checker::validate_device_types()
 	machine_config::token const tok(config.begin_configuration(config.root_device()));
 	for (device_type type : registered_device_types)
 	{
-		device_t *const dev = config.device_add("_tmp", type, 0);
+		device_t *const dev = config.device_add(type.shortname(), type, 0);
 
 		char const *name((dev->shortname() && *dev->shortname()) ? dev->shortname() : type.type().name());
 		std::string const description((dev->source() && *dev->source()) ? util::string_format("%s(%s)", core_filename_extract_base(dev->source()).c_str(), name) : name);
@@ -2188,7 +2206,18 @@ void validity_checker::validate_device_types()
 		if (unemulated & imperfect)
 			osd_printf_error("Device cannot have features that are both unemulated and imperfect (0x%08lX)\n", static_cast<unsigned long>(unemulated & imperfect));
 
-		config.device_remove("_tmp");
+		// give devices some of the same scrutiny that drivers get - necessary for cards not default for any slots
+		validate_roms(*dev);
+		validate_inputs(*dev);
+
+		// reset the device
+		m_current_device = nullptr;
+		m_current_ioport = nullptr;
+		m_region_map.clear();
+		m_ioport_set.clear();
+
+		// remove the device in preparation for re-using the machine configuration
+		config.device_remove(type.shortname());
 	}
 
 	// if we had warnings or errors, output
