@@ -7,9 +7,10 @@
     Olivetti M20 floppy-disk images
 
 *********************************************************************/
+#ifndef MAME_FORMATS_M20_DSK_H
+#define MAME_FORMATS_M20_DSK_H
 
-#ifndef M20_DSK_H
-#define M20_DSK_H
+#pragma once
 
 #include "flopimg.h"
 
@@ -17,8 +18,8 @@ class m20_format : public floppy_image_format_t {
 public:
 	m20_format();
 
-	virtual int identify(io_generic *io, UINT32 form_factor) override;
-	virtual bool load(io_generic *io, UINT32 form_factor, floppy_image *image) override;
+	virtual int identify(io_generic *io, uint32_t form_factor) override;
+	virtual bool load(io_generic *io, uint32_t form_factor, floppy_image *image) override;
 	virtual bool save(io_generic *io, floppy_image *image) override;
 
 	virtual const char *name() const override;
@@ -29,4 +30,4 @@ public:
 
 extern const floppy_format_type FLOPPY_M20_FORMAT;
 
-#endif /* M20_DSK_H */
+#endif // MAME_FORMATS_M20_DSK_H
