@@ -10,7 +10,6 @@
 
 #include "bitmap.h"
 
-#include <algorithm>
 #include <cassert>
 #include <new>
 
@@ -281,23 +280,25 @@ void bitmap_t::resize(int width, int height, int xslop, int yslop)
 	int new_rowpixels = compute_rowpixels(width, xslop);
 	uint32_t new_allocbytes = new_rowpixels * (height + 2 * yslop) * m_bpp / 8;
 
-	// if we need more memory, just realloc
 	if (new_allocbytes > m_allocbytes)
 	{
-		palette_t *palette = m_palette;
+		// if we need more memory, just realloc
+		palette_t *const palette = m_palette;
 		allocate(width, height, xslop, yslop);
 		set_palette(palette);
-		return;
 	}
+	else
+	{
 
-	// otherwise, reconfigure
-	m_rowpixels = new_rowpixels;
-	m_width = width;
-	m_height = height;
-	m_cliprect.set(0, width - 1, 0, height - 1);
+		// otherwise, reconfigure
+		m_rowpixels = new_rowpixels;
+		m_width = width;
+		m_height = height;
+		m_cliprect.set(0, width - 1, 0, height - 1);
 
-	// re-compute the base
-	compute_base(xslop, yslop);
+		// re-compute the base
+		compute_base(xslop, yslop);
+	}
 }
 
 /**
@@ -360,7 +361,7 @@ void bitmap_t::wrap(void *base, int width, int height, int rowpixels)
  * @param   subrect The subrect.
  */
 
-void bitmap_t::wrap(const bitmap_t &source, const rectangle &subrect)
+void bitmap_t::wrap(bitmap_t &source, const rectangle &subrect)
 {
 	assert(m_format == source.m_format);
 	assert(m_bpp == source.m_bpp);
@@ -406,7 +407,7 @@ void bitmap_t::set_palette(palette_t *palette)
 }
 
 /**
- * @fn  void bitmap_t::fill(uint32_t color, const rectangle &cliprect)
+ * @fn  void bitmap_t::fill(uint64_t color, const rectangle &bounds)
  *
  * @brief   -------------------------------------------------
  *            fill -- fill a bitmap with a solid color
@@ -416,10 +417,10 @@ void bitmap_t::set_palette(palette_t *palette)
  * @param   cliprect    The cliprect.
  */
 
-void bitmap_t::fill(uint32_t color, const rectangle &cliprect)
+void bitmap_t::fill(uint64_t color, const rectangle &bounds)
 {
 	// if we have a cliprect, intersect with that
-	rectangle fill(cliprect);
+	rectangle fill(bounds);
 	fill &= m_cliprect;
 	if (!fill.empty())
 	{
@@ -448,3 +449,13 @@ void bitmap_t::fill(uint32_t color, const rectangle &cliprect)
 		}
 	}
 }
+
+
+//**************************************************************************
+//  EXPLICIT TEMPLATE INSTANTIATIONS
+//**************************************************************************
+
+template class bitmap_specific<uint8_t>;
+template class bitmap_specific<uint16_t>;
+template class bitmap_specific<uint32_t>;
+template class bitmap_specific<uint64_t>;
