@@ -10,7 +10,6 @@
 #include "includes/harddriv.h"
 
 #include "cpu/tms32010/tms32010.h"
-#include "sound/volt_reg.h"
 #include "speaker.h"
 
 
@@ -455,7 +454,4 @@ void harddriv_sound_board_device::device_add_mconfig(machine_config &config)
 	SPEAKER(config, "speaker").front_center();
 
 	AM6012(config, m_dac, 0).add_route(ALL_OUTPUTS, "speaker", 0.5); // ls374d.75e + ls374d.90e + am6012
-	voltage_regulator_device &vref(VOLTAGE_REGULATOR(config, "vref"));
-	vref.add_route(0, "dac", 1.0, DAC_VREF_POS_INPUT);
-	vref.add_route(0, "dac", -1.0, DAC_VREF_NEG_INPUT);
 }
