@@ -14,6 +14,8 @@
 #include "rendlay.h"
 #include "speaker.h"
 
+namespace {
+
 class alto2_state : public driver_device
 {
 public:
@@ -26,11 +28,13 @@ public:
 	{ }
 
 	void init_alto2();
-	DECLARE_MACHINE_RESET(alto2);
 
 	void alto2(machine_config &config);
 
 protected:
+	virtual void device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr) override;
+
+private:
 	u16 kb_r(offs_t offset);
 	void utilout_w(u16 data);
 
@@ -40,7 +44,6 @@ protected:
 	optional_ioport m_io_config;
 	static const device_timer_id TIMER_VBLANK = 0;
 	emu_timer* m_vblank_timer;
-	virtual void device_timer(emu_timer &timer, device_timer_id id, int param, void *ptr) override;
 };
 
 /* Input Ports */
@@ -314,6 +317,8 @@ void alto2_state::device_timer(emu_timer &timer, device_timer_id id, int param,
 	}
 }
 
+} // Anonymous namespace
+
 /* Game Drivers */
 
 //    YEAR  NAME   PARENT  COMPAT  MACHINE  INPUT  CLASS        INIT        COMPANY  FULLNAME   FLAGS
