@@ -54,6 +54,7 @@ II Plus: RAM options reduced to 16/32/48 KB.
 
 #include "sound/spkrdev.h"
 
+#include "bus/a2bus/4play.h"
 #include "bus/a2bus/a2alfam2.h"
 #include "bus/a2bus/a2applicard.h"
 #include "bus/a2bus/a2arcadebd.h"
@@ -63,10 +64,12 @@ II Plus: RAM options reduced to 16/32/48 KB.
 #include "bus/a2bus/a2diskiing.h"
 #include "bus/a2bus/a2dx1.h"
 #include "bus/a2bus/a2echoii.h"
+#include "bus/a2bus/a2iwm.h"
 #include "bus/a2bus/a2mcms.h"
 #include "bus/a2bus/a2memexp.h"
 #include "bus/a2bus/a2midi.h"
 #include "bus/a2bus/a2mockingboard.h"
+#include "bus/a2bus/a2parprn.h"
 #include "bus/a2bus/a2pic.h"
 #include "bus/a2bus/a2sam.h"
 #include "bus/a2bus/a2scsi.h"
@@ -78,19 +81,21 @@ II Plus: RAM options reduced to 16/32/48 KB.
 #include "bus/a2bus/a2ultraterm.h"
 #include "bus/a2bus/a2videoterm.h"
 #include "bus/a2bus/a2zipdrive.h"
+#include "bus/a2bus/byte8251.h"
+#include "bus/a2bus/computereyes2.h"
+#include "bus/a2bus/ccs7710.h"
 #include "bus/a2bus/ezcgi.h"
+#include "bus/a2bus/grapplerplus.h"
 #include "bus/a2bus/laser128.h"
 #include "bus/a2bus/mouse.h"
 #include "bus/a2bus/ramcard128k.h"
 #include "bus/a2bus/ramcard16k.h"
-#include "bus/a2bus/timemasterho.h"
-#include "bus/a2bus/ssprite.h"
 #include "bus/a2bus/ssbapple.h"
-#include "bus/a2bus/4play.h"
-#include "bus/a2bus/computereyes2.h"
+#include "bus/a2bus/ssprite.h"
+#include "bus/a2bus/suprterminal.h"
+#include "bus/a2bus/timemasterho.h"
 #include "bus/a2bus/transwarp.h"
-#include "bus/a2bus/byte8251.h"
-#include "bus/a2bus/a2iwm.h"
+#include "bus/a2bus/uniprint.h"
 
 #include "bus/a2gameio/gameio.h"
 
@@ -156,33 +161,33 @@ public:
 	virtual void machine_start() override;
 	virtual void machine_reset() override;
 
-	uint32_t screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
-	uint32_t screen_update_jp(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
-	uint32_t screen_update_dodo(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
+	u32 screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
+	u32 screen_update_jp(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
+	u32 screen_update_dodo(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 
-	uint8_t ram_r(offs_t offset);
-	void ram_w(offs_t offset, uint8_t data);
-	uint8_t keyb_data_r();
-	uint8_t keyb_strobe_r();
-	void keyb_strobe_w(uint8_t data);
-	uint8_t cassette_toggle_r();
-	void cassette_toggle_w(uint8_t data);
-	uint8_t speaker_toggle_r();
-	void speaker_toggle_w(uint8_t data);
-	uint8_t utility_strobe_r();
-	void utility_strobe_w(uint8_t data);
-	uint8_t switches_r(offs_t offset);
-	uint8_t flags_r(offs_t offset);
-	uint8_t controller_strobe_r();
-	void controller_strobe_w(uint8_t data);
-	uint8_t c080_r(offs_t offset);
-	void c080_w(offs_t offset, uint8_t data);
-	uint8_t c100_r(offs_t offset);
-	void c100_w(offs_t offset, uint8_t data);
-	uint8_t c800_r(offs_t offset);
-	void c800_w(offs_t offset, uint8_t data);
-	uint8_t inh_r(offs_t offset);
-	void inh_w(offs_t offset, uint8_t data);
+	u8 ram_r(offs_t offset);
+	void ram_w(offs_t offset, u8 data);
+	u8 keyb_data_r();
+	u8 keyb_strobe_r();
+	void keyb_strobe_w(u8 data);
+	u8 cassette_toggle_r();
+	void cassette_toggle_w(u8 data);
+	u8 speaker_toggle_r();
+	void speaker_toggle_w(u8 data);
+	u8 utility_strobe_r();
+	void utility_strobe_w(u8 data);
+	u8 switches_r(offs_t offset);
+	u8 flags_r(offs_t offset);
+	u8 controller_strobe_r();
+	void controller_strobe_w(u8 data);
+	u8 c080_r(offs_t offset);
+	void c080_w(offs_t offset, u8 data);
+	u8 c100_r(offs_t offset);
+	void c100_w(offs_t offset, u8 data);
+	u8 c800_r(offs_t offset);
+	void c800_w(offs_t offset, u8 data);
+	u8 inh_r(offs_t offset);
+	void inh_w(offs_t offset, u8 data);
 	DECLARE_WRITE_LINE_MEMBER(a2bus_irq_w);
 	DECLARE_WRITE_LINE_MEMBER(a2bus_nmi_w);
 	DECLARE_WRITE_LINE_MEMBER(a2bus_inh_w);
@@ -199,23 +204,20 @@ public:
 	void apple2p(machine_config &config);
 	void apple2_map(address_map &map);
 	void inhbank_map(address_map &map);
+
 private:
-	int m_speaker_state;
-	int m_cassette_state;
+	int m_speaker_state, m_cassette_state;
 
-	double m_joystick_x1_time;
-	double m_joystick_y1_time;
-	double m_joystick_x2_time;
-	double m_joystick_y2_time;
+	double m_joystick_x1_time, m_joystick_y1_time, m_joystick_x2_time, m_joystick_y2_time;
 
-	uint16_t m_lastchar, m_strobe;
-	uint8_t m_transchar;
+	u16 m_lastchar, m_strobe;
+	u8 m_transchar;
 	bool m_anykeydown;
 
 	int m_inh_slot;
 	int m_cnxx_slot;
 
-	uint8_t *m_ram_ptr;
+	u8 *m_ram_ptr;
 	int m_ram_size;
 
 	int m_inh_bank;
@@ -224,7 +226,7 @@ private:
 
 	device_a2bus_card_interface *m_slotdevice[8];
 
-	uint8_t read_floatingbus();
+	u8 read_floatingbus();
 
 	offs_t dasm_trampoline(std::ostream &stream, offs_t pc, const util::disasm_interface::data_buffer &opcodes, const util::disasm_interface::data_buffer &params);
 };
@@ -403,7 +405,7 @@ TIMER_DEVICE_CALLBACK_MEMBER(apple2_state::apple2_interrupt)
 }
 
 
-uint32_t apple2_state::screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
+u32 apple2_state::screen_update(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	// always update the flash timer here so it's smooth regardless of mode switches
 	m_video->m_flash = ((machine().time() * 4).seconds() & 1) ? true : false;
@@ -464,7 +466,7 @@ uint32_t apple2_state::screen_update(screen_device &screen, bitmap_ind16 &bitmap
 	return 0;
 }
 
-uint32_t apple2_state::screen_update_jp(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
+u32 apple2_state::screen_update_jp(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	// always update the flash timer here so it's smooth regardless of mode switches
 	m_video->m_flash = ((machine().time() * 4).seconds() & 1) ? true : false;
@@ -504,7 +506,7 @@ uint32_t apple2_state::screen_update_jp(screen_device &screen, bitmap_ind16 &bit
 	return 0;
 }
 
-uint32_t apple2_state::screen_update_dodo(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
+u32 apple2_state::screen_update_dodo(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
 	// always update the flash timer here so it's smooth regardless of mode switches
 	m_video->m_flash = ((machine().time() * 4).seconds() & 1) ? true : false;
@@ -548,75 +550,75 @@ uint32_t apple2_state::screen_update_dodo(screen_device &screen, bitmap_ind16 &b
     I/O
 ***************************************************************************/
 
-uint8_t apple2_state::keyb_data_r()
+u8 apple2_state::keyb_data_r()
 {
 	// keyboard latch
 	return m_transchar | m_strobe;
 }
 
-uint8_t apple2_state::keyb_strobe_r()
+u8 apple2_state::keyb_strobe_r()
 {
 	// reads any key down, clears strobe
-	uint8_t rv = m_transchar | (m_anykeydown ? 0x80 : 0x00);
+	u8 rv = m_transchar | (m_anykeydown ? 0x80 : 0x00);
 	if (!machine().side_effects_disabled())
 		m_strobe = 0;
 	return rv;
 }
 
-void apple2_state::keyb_strobe_w(uint8_t data)
+void apple2_state::keyb_strobe_w(u8 data)
 {
 	// clear keyboard latch
 	m_strobe = 0;
 }
 
-uint8_t apple2_state::cassette_toggle_r()
+u8 apple2_state::cassette_toggle_r()
 {
 	if (!machine().side_effects_disabled())
 		cassette_toggle_w(0);
 	return read_floatingbus();
 }
 
-void apple2_state::cassette_toggle_w(uint8_t data)
+void apple2_state::cassette_toggle_w(u8 data)
 {
 	m_cassette_state ^= 1;
 	m_cassette->output(m_cassette_state ? 1.0f : -1.0f);
 }
 
-uint8_t apple2_state::speaker_toggle_r()
+u8 apple2_state::speaker_toggle_r()
 {
 	if (!machine().side_effects_disabled())
 		speaker_toggle_w(0);
 	return read_floatingbus();
 }
 
-void apple2_state::speaker_toggle_w(uint8_t data)
+void apple2_state::speaker_toggle_w(u8 data)
 {
 	m_speaker_state ^= 1;
 	m_speaker->level_w(m_speaker_state);
 }
 
-uint8_t apple2_state::utility_strobe_r()
+u8 apple2_state::utility_strobe_r()
 {
 	if (!machine().side_effects_disabled())
 		utility_strobe_w(0);
 	return read_floatingbus();
 }
 
-void apple2_state::utility_strobe_w(uint8_t data)
+void apple2_state::utility_strobe_w(u8 data)
 {
 	// low pulse on pin 5 of game I/O connector
 	m_gameio->strobe_w(0);
 	m_gameio->strobe_w(1);
 }
 
-uint8_t apple2_state::switches_r(offs_t offset)
+u8 apple2_state::switches_r(offs_t offset)
 {
 	if (!machine().side_effects_disabled())
 		m_softlatch->write_bit((offset & 0x0e) >> 1, offset & 0x01);
 	return read_floatingbus();
 }
 
-uint8_t apple2_state::flags_r(offs_t offset)
+u8 apple2_state::flags_r(offs_t offset)
 {
 	u8 uFloatingBus7 = read_floatingbus() & 0x7f;
 
@@ -657,14 +659,14 @@ uint8_t apple2_state::flags_r(offs_t offset)
 	return 0;
 }
 
-uint8_t apple2_state::controller_strobe_r()
+u8 apple2_state::controller_strobe_r()
 {
 	if (!machine().side_effects_disabled())
 		controller_strobe_w(0);
 	return read_floatingbus();
 }
 
-void apple2_state::controller_strobe_w(uint8_t data)
+void apple2_state::controller_strobe_w(u8 data)
 {
 	m_joystick_x1_time = machine().time().as_double() + m_x_calibration * m_gameio->pdl0_r();
 	m_joystick_y1_time = machine().time().as_double() + m_y_calibration * m_gameio->pdl1_r();
@@ -672,7 +674,7 @@ void apple2_state::controller_strobe_w(uint8_t data)
 	m_joystick_y2_time = machine().time().as_double() + m_y_calibration * m_gameio->pdl3_r();
 }
 
-uint8_t apple2_state::c080_r(offs_t offset)
+u8 apple2_state::c080_r(offs_t offset)
 {
 	if(!machine().side_effects_disabled())
 	{
@@ -690,7 +692,7 @@ uint8_t apple2_state::c080_r(offs_t offset)
 	return read_floatingbus();
 }
 
-void apple2_state::c080_w(offs_t offset, uint8_t data)
+void apple2_state::c080_w(offs_t offset, u8 data)
 {
 	int slot;
 
@@ -703,7 +705,7 @@ void apple2_state::c080_w(offs_t offset, uint8_t data)
 	}
 }
 
-uint8_t apple2_state::c100_r(offs_t offset)
+u8 apple2_state::c100_r(offs_t offset)
 {
 	int slotnum;
 
@@ -722,7 +724,7 @@ uint8_t apple2_state::c100_r(offs_t offset)
 	return read_floatingbus();
 }
 
-void apple2_state::c100_w(offs_t offset, uint8_t data)
+void apple2_state::c100_w(offs_t offset, u8 data)
 {
 	int slotnum;
 
@@ -739,11 +741,11 @@ void apple2_state::c100_w(offs_t offset, uint8_t data)
 	}
 }
 
-uint8_t apple2_state::c800_r(offs_t offset)
+u8 apple2_state::c800_r(offs_t offset)
 {
 	if (offset == 0x7ff)
 	{
-		uint8_t rv = 0xff;
+		u8 rv = 0xff;
 
 		if ((m_cnxx_slot != -1) && (m_slotdevice[m_cnxx_slot] != nullptr))
 		{
@@ -766,7 +768,7 @@ uint8_t apple2_state::c800_r(offs_t offset)
 	return read_floatingbus();
 }
 
-void apple2_state::c800_w(offs_t offset, uint8_t data)
+void apple2_state::c800_w(offs_t offset, u8 data)
 {
 	if ((m_cnxx_slot != -1) && (m_slotdevice[m_cnxx_slot] != nullptr))
 	{
@@ -784,7 +786,7 @@ void apple2_state::c800_w(offs_t offset, uint8_t data)
 	}
 }
 
-uint8_t apple2_state::inh_r(offs_t offset)
+u8 apple2_state::inh_r(offs_t offset)
 {
 	if (m_inh_slot != -1)
 	{
@@ -795,7 +797,7 @@ uint8_t apple2_state::inh_r(offs_t offset)
 	return read_floatingbus();
 }
 
-void apple2_state::inh_w(offs_t offset, uint8_t data)
+void apple2_state::inh_w(offs_t offset, u8 data)
 {
 	if ((m_inh_slot != -1) && (m_slotdevice[m_inh_slot] != nullptr))
 	{
@@ -803,14 +805,11 @@ void apple2_state::inh_w(offs_t offset, uint8_t data)
 	}
 }
 
-// floating bus code from old machine/apple2: needs to be reworked based on real beam position to enable e.g. Bob Bishop's screen splitter
-uint8_t apple2_state::read_floatingbus()
+// floating bus code from old machine/apple2: now works reasonably well with French Touch and Deater "vapor lock" stuff
+u8 apple2_state::read_floatingbus()
 {
 	enum
 	{
-		// scanner types
-		kScannerNone = 0, kScannerApple2, kScannerApple2e,
-
 		// scanner constants
 		kHBurstClock      =    53, // clock when Color Burst starts
 		kHBurstClocks     =     4, // clocks per Color Burst duration
@@ -855,8 +854,7 @@ uint8_t apple2_state::read_floatingbus()
 	// ScanCycles = ScanLines * kHClocks;
 
 	// calculate horizontal scanning state
-	//
-	h_clock = (i + kHPEClock) % kHClocks; // which horizontal scanning clock
+	h_clock = (i + 63) % kHClocks; // which horizontal scanning clock
 	h_state = kHClock0State + h_clock; // H state bits
 	if (h_clock >= kHPresetClock) // check for horizontal preset
 	{
@@ -871,7 +869,7 @@ uint8_t apple2_state::read_floatingbus()
 
 	// calculate vertical scanning state
 	//
-	v_line  = (i / kHClocks) + 188; // which vertical scanning line
+	v_line  = (i / kHClocks) + 192; // which vertical scanning line
 	v_state = kVLine0State + v_line; // V state bits
 	if ((v_line >= kVPresetLine)) // check for previous vertical state preset
 	{
@@ -922,22 +920,21 @@ uint8_t apple2_state::read_floatingbus()
 	{
 		// N: text, so no higher address bits unless Apple ][, not Apple //e
 		//
-		if ((1) && // Apple ][? // FIX: check for Apple ][? (FB is most useful in old games)
-			(kHPEClock <= h_clock) && // Y: HBL?
+		if ((kHPEClock <= h_clock) && // Y: HBL?
 			(h_clock <= (kHClocks - 1)))
 		{
 			address |= 1 << 12; // Y: a12 (add $1000 to address!)
 		}
 	}
 
-	return m_ram_ptr[address % m_ram_size]; // FIX: this seems to work, but is it right!?
+	return m_ram_ptr[address % m_ram_size];
 }
 
 /***************************************************************************
     ADDRESS MAP
 ***************************************************************************/
 
-uint8_t apple2_state::ram_r(offs_t offset)
+u8 apple2_state::ram_r(offs_t offset)
 {
 	if (offset < m_ram_size)
 	{
@@ -947,7 +944,7 @@ uint8_t apple2_state::ram_r(offs_t offset)
 	return 0xff;
 }
 
-void apple2_state::ram_w(offs_t offset, uint8_t data)
+void apple2_state::ram_w(offs_t offset, u8 data)
 {
 	if (offset < m_ram_size)
 	{
@@ -1003,7 +1000,7 @@ READ_LINE_MEMBER(apple2_state::ay3600_control_r)
 	return CLEAR_LINE;
 }
 
-static const uint8_t a2_key_remap[0x32][4] =
+static const u8 a2_key_remap[0x32][4] =
 {
 /*    norm shft ctrl both */
 	{ 0x33,0x23,0x33,0x23 },    /* 3 #     00     */
@@ -1063,6 +1060,15 @@ WRITE_LINE_MEMBER(apple2_state::ay3600_data_ready_w)
 	if (state == ASSERT_LINE)
 	{
 		int mod = 0;
+
+		// if the user presses a valid key to start the driver from the info screen,
+		// we will see that key.  ignore keys in the first 25,000 cycles (in my tests,
+		// the unwanted key shows up at 17030 cycles)
+		if (m_maincpu->total_cycles() < 25000)
+		{
+			return;
+		}
+
 		m_lastchar = m_ay3600->b_r();
 
 		mod = (m_kbspecial->read() & 0x06) ? 0x01 : 0x00;
@@ -1303,7 +1309,9 @@ static void apple2_cards(device_slot_interface &device)
 	device.option_add("ultraterm", A2BUS_ULTRATERM);    /* Videx UltraTerm (original) */
 	device.option_add("ultratermenh", A2BUS_ULTRATERMENH);    /* Videx UltraTerm (enhanced //e) */
 	device.option_add("aevm80", A2BUS_AEVIEWMASTER80);    /* Applied Engineering ViewMaster 80 */
-	device.option_add("parallel", A2BUS_PIC);   /* Apple Parallel Interface Card */
+	device.option_add("parprn", A2BUS_PARPRN);   /* Apple II Parallel Printer Interface Card */
+	device.option_add("parallel", A2BUS_PIC);   /* Apple II Parallel Interface Card */
+	device.option_add("grapplerplus", A2BUS_GRAPPLERPLUS); /* Orange Micro Grappler+ Printer Interface card */
 	device.option_add("corvus", A2BUS_CORVUS);  /* Corvus flat-cable HDD interface (see notes in a2corvus.c) */
 	device.option_add("mcms1", A2BUS_MCMS1);  /* Mountain Computer Music System, card 1 of 2 */
 	device.option_add("mcms2", A2BUS_MCMS2);  /* Mountain Computer Music System, card 2 of 2.  must be in card 1's slot + 1! */
@@ -1321,6 +1329,9 @@ static void apple2_cards(device_slot_interface &device)
 	device.option_add("applesurance", A2BUS_APPLESURANCE);  /* Applesurance Diagnostic Controller */
 //  device.option_add("magicmusician", A2BUS_MAGICMUSICIAN);    /* Magic Musician Card */
 	device.option_add("byte8251", A2BUS_BYTE8251); /* BYTE Magazine 8251 serial card */
+	device.option_add("suprterm", A2BUS_SUPRTERMINAL); /* M&R Enterprises SUP'R'TERMINAL 80-column card */
+	device.option_add("uniprint", A2BUS_UNIPRINT);     /* Videx Uniprint parallel printer card */
+	device.option_add("ccs7710", A2BUS_CCS7710); /* California Computer Systems Model 7710 Asynchronous Serial Interface */
 }
 
 void apple2_state::apple2_common(machine_config &config)
@@ -1344,7 +1355,7 @@ void apple2_state::apple2_common(machine_config &config)
 
 	/* sound hardware */
 	SPEAKER(config, "mono").front_center();
-	SPEAKER_SOUND(config, A2_SPEAKER_TAG).add_route(ALL_OUTPUTS, "mono", 0.5);
+	SPEAKER_SOUND(config, A2_SPEAKER_TAG).add_route(ALL_OUTPUTS, "mono", 0.4);
 
 	/* /INH banking */
 	ADDRESS_MAP_BANK(config, A2_UPPERBANK_TAG).set_map(&apple2_state::inhbank_map).set_options(ENDIANNESS_LITTLE, 8, 32, 0x3000);
