@@ -26,7 +26,6 @@
 
 #include "machine/eeprompar.h"
 #include "machine/watchdog.h"
-#include "sound/volt_reg.h"
 #include "speaker.h"
 
 #include "rendlay.h"
@@ -144,6 +143,12 @@ void cyberbal_state::main_map(address_map &map)
 	map(0xffc000, 0xffffff).ram().share("mainram");
 }
 
+void cyberbal_state::tournament_map(address_map &map)
+{
+	main_map(map);
+	map(0x018000, 0x019fff).mirror(0x6000).bankr(m_slapstic_bank);
+}
+
 
 
 /*************************************
@@ -415,7 +420,9 @@ void cyberbal_state::cyberbalt(machine_config &config)
 	cyberbal_base(config);
 	EEPROM_2816(config, "eeprom").lock_after_write(true);
 
-	SLAPSTIC(config, m_slapstic, 116, true);
+	SLAPSTIC(config, m_slapstic, 116);
+	m_slapstic->set_bank(m_slapstic_bank);
+	m_maincpu->set_addrmap(AS_PROGRAM, &cyberbal_state::tournament_map);
 }
 
 void cyberbal2p_state::cyberbal2p(machine_config &config)
@@ -994,7 +1001,11 @@ ROM_END
 
 void cyberbal_state::init_cyberbalt()
 {
-	m_slapstic->legacy_configure(*m_maincpu, 0x018000, 0, memregion("maincpu")->base() + 0x18000);
+	m_slapstic_bank->configure_entries(0, 4, memregion("maincpu")->base() + 0x18000, 0x2000);
+	m_maincpu->space(AS_PROGRAM).install_readwrite_tap(0x18000, 0x1ffff, 0, "slapstic",
+													   [this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); },
+													   [this](offs_t offset, u16 &data, u16 mem_mask) { m_slapstic->tweak(offset >> 1); });
+
 }
 
 
