@@ -930,7 +930,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-MACHINE_START_MEMBER(gameplan_state,gameplan)
+void gameplan_state::machine_start()
 {
 	/* register for save states */
 	save_item(NAME(m_current_port));
@@ -938,13 +938,10 @@ MACHINE_START_MEMBER(gameplan_state,gameplan)
 	save_item(NAME(m_video_y));
 	save_item(NAME(m_video_command));
 	save_item(NAME(m_video_data));
-
-	/* this is needed for trivia quest */
-	m_via_0->write_pb5(1);
 }
 
 
-MACHINE_RESET_MEMBER(gameplan_state,gameplan)
+void gameplan_state::machine_reset()
 {
 	m_current_port = 0;
 	m_video_x = 0;
