@@ -321,14 +321,13 @@ void gts3a_state::palette_init(palette_device &palette)
 
 MC6845_UPDATE_ROW( gts3a_state::crtc_update_row )
 {
-	const rgb_t *palette = m_palette->palette()->entry_list_raw();
+	rgb_t const *const palette = m_palette->palette()->entry_list_raw();
 	uint8_t gfx=0;
-	uint16_t mem,x;
-	uint32_t *p = &bitmap.pix32(y);
+	uint32_t *p = &bitmap.pix(y);
 
-	for (x = 0; x < x_count; x++)
+	for (uint16_t x = 0; x < x_count; x++)
 	{
-		mem = (ma + x) & 0xfff;mem++;
+		uint16_t mem = (ma + x) & 0xfff;mem++;
 		gfx = 4;//m_p_chargen[(chr<<4) | ra] ^ inv;
 
 		/* Display a scanline of a character */
