@@ -65,6 +65,8 @@ TODO:
 #include "speaker.h"
 
 
+namespace {
+
 class jr100_state : public driver_device
 {
 public:
@@ -73,23 +75,26 @@ public:
 		, m_ram(*this, "ram")
 		, m_pcg(*this, "pcg")
 		, m_vram(*this, "vram")
-		, m_rom(*this, "rom")
+		, m_rom(*this, "maincpu")
 		, m_via(*this, "via")
 		, m_cassette(*this, "cassette")
 		, m_speaker(*this, "speaker")
 		, m_region_maincpu(*this, "maincpu")
 		, m_io_keyboard(*this, "LINE%u", 0)
 		, m_maincpu(*this, "maincpu")
+		, m_sound_timer(nullptr)
 	{ }
 
 	void jr100(machine_config &config);
 
+protected:
+	virtual void machine_start() override;
+	virtual void machine_reset() override;
+
 private:
 	uint8_t m_keyboard_line;
 	bool m_use_pcg;
 	bool m_pb7;
-	virtual void machine_start() override;
-	virtual void machine_reset() override;
 	uint32_t screen_update_jr100(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	TIMER_CALLBACK_MEMBER(sound_tick);
 	uint8_t pb_r();
@@ -104,7 +109,7 @@ private:
 	required_shared_ptr<uint8_t> m_ram;
 	required_shared_ptr<uint8_t> m_pcg;
 	required_shared_ptr<uint8_t> m_vram;
-	required_shared_ptr<uint8_t> m_rom;
+	required_region_ptr<uint8_t> m_rom;
 	required_device<via6522_device> m_via;
 	required_device<cassette_image_device> m_cassette;
 	required_device<speaker_sound_device> m_speaker;
@@ -128,7 +133,7 @@ void jr100_state::mem_map(address_map &map)
 	//map(0xcc00, 0xcfff).;   expansion i/o
 	//map(0xd000, 0xd7ff).rom();   expansion rom for printer control
 	//map(0xd800, 0xdfff).rom();   expansion rom
-	map(0xe000, 0xffff).rom().share("rom").region("maincpu",0);
+	map(0xe000, 0xffff).rom().region("maincpu", 0);
 }
 
 // Input ports - names in [ ] are screen actions; otherwise the text is literally printed onscreen
@@ -216,20 +221,19 @@ void jr100_state::machine_reset()
 
 uint32_t jr100_state::screen_update_jr100(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect)
 {
-	bool attr;
-	u8 y,ra,gfx,chr;
-	u16 x,sy=0,ma=0;
+	u16 sy=0,ma=0;
 
-	for (y = 0; y < 24; y++)
+	for (u8 y = 0; y < 24; y++)
 	{
-		for (ra = 0; ra < 8; ra++)
+		for (u8 ra = 0; ra < 8; ra++)
 		{
-			uint16_t *p = &bitmap.pix16(sy++);
-			for (x = ma; x < ma + 32; x++)
+			uint16_t *p = &bitmap.pix(sy++);
+			for (u16 x = ma; x < ma + 32; x++)
 			{
-				chr = m_vram[x];
-				attr = BIT(chr, 7);
+				u8 chr = m_vram[x];
+				bool const attr = BIT(chr, 7);
 				chr &= 0x7f;
+				u8 gfx;
 				// ATTR is inverted for normal char or use PCG in case of CMODE1
 				if (m_use_pcg && attr && (chr < 32))
 					gfx = m_pcg[(chr<<3) | ra];
@@ -423,6 +427,9 @@ ROM_START( jr100u )
 	ROM_LOAD( "jr100u.ic5", 0x0000, 0x2000, CRC(f589dd8d) SHA1(78a51f2ae055bf4dc1b0887a6277f5dbbd8ba512))
 ROM_END
 
+} // Anonymous namespace
+
+
 /* Driver */
 
 //    YEAR  NAME    PARENT  COMPAT  MACHINE  INPUT  CLASS        INIT        COMPANY      FULLNAME   FLAGS
