@@ -90,6 +90,8 @@ Sonic Hedgehog 2           171-6215A   837-6963-62       610-0239-62         MPR
 
 
 
+namespace {
+
 class mtech_state : public md_base_state
 {
 public:
@@ -114,6 +116,9 @@ public:
 	void init_mt_crt();
 	void init_mt_slot();
 
+protected:
+	virtual void machine_reset() override;
+
 private:
 
 	void megatech(machine_config &config);
@@ -137,7 +142,6 @@ private:
 	uint8_t sms_ioport_dd_r();
 	void mt_sms_standard_rom_bank_w(address_space &space, offs_t offset, uint8_t data);
 
-	DECLARE_MACHINE_RESET(megatech);
 
 	image_init_result load_cart(device_image_interface &image, generic_slot_device *slot, int gameno);
 	DECLARE_DEVICE_IMAGE_LOAD_MEMBER( mt_cart1 ) { return load_cart(image, m_cart1, 0); }
@@ -406,9 +410,6 @@ void mtech_state::set_genz80_as_md()
 {
 	address_space &prg = m_z80snd->space(AS_PROGRAM);
 
-	prg.install_readwrite_bank(0x0000, 0x1fff, "bank1");
-	machine().root_device().membank("bank1")->set_base(m_genz80.z80_prgram.get());
-
 	prg.install_ram(0x0000, 0x1fff, m_genz80.z80_prgram.get());
 
 	prg.install_readwrite_handler(0x4000, 0x4003, read8sm_delegate(*m_ymsnd, FUNC(ym2612_device::read)), write8sm_delegate(*m_ymsnd, FUNC(ym2612_device::write)));
@@ -627,8 +628,8 @@ uint32_t mtech_state::screen_update_main(screen_device &screen, bitmap_rgb32 &bi
 		// when launching megatech + both sms and megadrive games, the following would be needed...
 		for (int y = 0; y < 224; y++)
 		{
-			uint32_t* lineptr = &bitmap.pix32(y);
-			uint32_t* srcptr =  &m_vdp->get_bitmap().pix32(y + sega315_5124_device::TBORDER_START + sega315_5124_device::NTSC_224_TBORDER_HEIGHT);
+			uint32_t* lineptr = &bitmap.pix(y);
+			uint32_t* srcptr =  &m_vdp->get_bitmap().pix(y + sega315_5124_device::TBORDER_START + sega315_5124_device::NTSC_224_TBORDER_HEIGHT);
 
 			for (int x = 0; x < sega315_5124_device::WIDTH; x++)
 				lineptr[x] = srcptr[x];
@@ -644,30 +645,32 @@ WRITE_LINE_MEMBER(mtech_state::screen_vblank_main)
 		screen_vblank_megadriv(state);
 }
 
-MACHINE_RESET_MEMBER(mtech_state, megatech)
+void mtech_state::machine_reset()
 {
 	m_mt_bank_addr = 0;
-	MACHINE_RESET_CALL_MEMBER(megadriv);
+	md_base_state::machine_reset();
+
+	for (int i = 0; i < 8; i++)
+		m_cart_reg[i] = nullptr;
 
-	std::string region_tag;
 	if (m_cart1->get_rom_size() > 0)
-		m_cart_reg[0] = memregion(region_tag.assign(m_cart1->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[0] = memregion(std::string(m_cart1->tag()) + GENERIC_ROM_REGION_TAG);
 	else
 		m_cart_reg[0] = memregion(":mt_slot1:cart");
 	if (m_cart2)
-		m_cart_reg[1] = memregion(region_tag.assign(m_cart2->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[1] = memregion(std::string(m_cart2->tag()) + GENERIC_ROM_REGION_TAG);
 	if (m_cart3)
-		m_cart_reg[2] = memregion(region_tag.assign(m_cart3->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[2] = memregion(std::string(m_cart3->tag()) + GENERIC_ROM_REGION_TAG);
 	if (m_cart4)
-		m_cart_reg[3] = memregion(region_tag.assign(m_cart4->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[3] = memregion(std::string(m_cart4->tag()) + GENERIC_ROM_REGION_TAG);
 	if (m_cart5)
-		m_cart_reg[4] = memregion(region_tag.assign(m_cart5->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[4] = memregion(std::string(m_cart5->tag()) + GENERIC_ROM_REGION_TAG);
 	if (m_cart6)
-		m_cart_reg[5] = memregion(region_tag.assign(m_cart6->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[5] = memregion(std::string(m_cart6->tag()) + GENERIC_ROM_REGION_TAG);
 	if (m_cart7)
-		m_cart_reg[6] = memregion(region_tag.assign(m_cart7->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[6] = memregion(std::string(m_cart7->tag()) + GENERIC_ROM_REGION_TAG);
 	if (m_cart8)
-		m_cart_reg[7] = memregion(region_tag.assign(m_cart8->tag()).append(GENERIC_ROM_REGION_TAG));
+		m_cart_reg[7] = memregion(std::string(m_cart8->tag()) + GENERIC_ROM_REGION_TAG);
 
 	switch_cart(0);
 }
@@ -702,8 +705,6 @@ void mtech_state::megatech(machine_config &config)
 	io2.in_porte_cb().set(FUNC(mtech_state::bios_porte_r));
 	io2.out_porte_cb().set(FUNC(mtech_state::bios_porte_w));
 
-	MCFG_MACHINE_RESET_OVERRIDE(mtech_state, megatech)
-
 	config.set_default_layout(layout_dualhovu);
 
 	screen_device &screen(*subdevice<screen_device>("megadriv"));
@@ -1411,6 +1412,8 @@ ROM_START( mt_soni2 ) /* Sonic The Hedgehog 2 */
 	ROM_REGION( 0x01, "sms_pin", ROMREGION_ERASE00 )
 ROM_END
 
+} // Anonymous namespace
+
 
 
 /* nn */ /* nn is part of the instruction rom name, should there be a game for each number? */
