@@ -17,7 +17,8 @@ instead of black, otherwise it's the same game.
 
 TODO:
 - does not work, most likely due to incomplete cpu emulation (unemulated timer registers),
-  could also be a bad rom dump on top of that
+  could also be a bad rom dump on top of that - even when adding IRQ3 with a hack, it
+  doesn't do much at all
 - is 1988 version the same ROM?
 
 ******************************************************************************/
@@ -27,7 +28,6 @@ TODO:
 #include "cpu/m6800/m6801.h"
 #include "machine/sensorboard.h"
 #include "sound/dac.h"
-#include "sound/volt_reg.h"
 
 #include "speaker.h"
 
@@ -54,7 +54,7 @@ private:
 	// devices/pointers
 	required_device<hd6303y_cpu_device> m_maincpu;
 	required_device<sensorboard_device> m_board;
-	optional_device<dac_bit_interface> m_dac;
+	required_device<dac_bit_interface> m_dac;
 
 	void main_map(address_map &map);
 };
@@ -106,6 +106,10 @@ void supremo_state::supremo(machine_config &config)
 	HD6303Y(config, m_maincpu, 8_MHz_XTAL);
 	m_maincpu->set_addrmap(AS_PROGRAM, &supremo_state::main_map);
 
+	// THIS IS A HACK, vector @ 0xffec, use ROM_COPY
+	//const attotime irq_period = attotime::from_ticks(4 * 128 * 10, 8_MHz_XTAL);
+	//m_maincpu->set_periodic_int(FUNC(supremo_state::irq0_line_hold), irq_period);
+
 	SENSORBOARD(config, m_board).set_type(sensorboard_device::BUTTONS);
 	m_board->init_cb().set(m_board, FUNC(sensorboard_device::preset_chess));
 	m_board->set_delay(attotime::from_msec(150));
@@ -113,7 +117,6 @@ void supremo_state::supremo(machine_config &config)
 	/* sound hardware */
 	SPEAKER(config, "speaker").front_center();
 	DAC_1BIT(config, m_dac).add_route(ALL_OUTPUTS, "speaker", 0.25);
-	VOLTAGE_REGULATOR(config, "vref").add_route(0, "dac", 1.0, DAC_VREF_POS_INPUT);
 }
 
 
@@ -124,7 +127,7 @@ void supremo_state::supremo(machine_config &config)
 
 ROM_START( supremo )
 	ROM_REGION( 0x10000, "maincpu", 0 )
-	ROM_LOAD("sp_a10.u5", 0x8000, 0x8000, CRC(745d010f) SHA1(365a8e2afcf63678ba0161b9082f6439a9d78c9f) )
+	ROM_LOAD("sp_a10.u5", 0x8000, 0x8000, BAD_DUMP CRC(745d010f) SHA1(365a8e2afcf63678ba0161b9082f6439a9d78c9f) )
 ROM_END
 
 } // anonymous namespace
