@@ -100,7 +100,7 @@ TODO:
 #include "speaker.h"
 
 
-WRITE16_MEMBER(playmark_state::coinctrl_w)
+void playmark_state::coinctrl_w(offs_t offset, uint16_t data, uint16_t mem_mask)
 {
 	if (ACCESSING_BITS_8_15)
 	{
@@ -118,7 +118,7 @@ WRITE16_MEMBER(playmark_state::coinctrl_w)
 
 ***************************************************************************/
 
-WRITE16_MEMBER(playmark_state::wbeachvl_coin_eeprom_w)
+void playmark_state::wbeachvl_coin_eeprom_w(offs_t offset, uint16_t data, uint16_t mem_mask)
 {
 	if (ACCESSING_BITS_0_7)
 	{
@@ -135,7 +135,7 @@ WRITE16_MEMBER(playmark_state::wbeachvl_coin_eeprom_w)
 	}
 }
 
-WRITE16_MEMBER(playmark_state::hotmind_coin_eeprom_w)
+void playmark_state::hotmind_coin_eeprom_w(offs_t offset, uint16_t data, uint16_t mem_mask)
 {
 	if (ACCESSING_BITS_0_7)
 	{
@@ -163,7 +163,7 @@ WRITE16_MEMBER(playmark_state::hotmind_coin_eeprom_w)
 	}
 }
 
-WRITE16_MEMBER(playmark_state::luckboomh_dispenser_w)
+void playmark_state::luckboomh_dispenser_w(offs_t offset, uint16_t data, uint16_t mem_mask)
 {
 	if (ACCESSING_BITS_0_7)
 	{
@@ -187,13 +187,13 @@ WRITE16_MEMBER(playmark_state::luckboomh_dispenser_w)
 	}
 }
 
-WRITE16_MEMBER(playmark_state::hrdtimes_coin_w)
+void playmark_state::hrdtimes_coin_w(uint16_t data)
 {
 	machine().bookkeeping().coin_counter_w(0, data & 0x01);
 	machine().bookkeeping().coin_counter_w(1, data & 0x02);
 }
 
-WRITE16_MEMBER(playmark_state::playmark_snd_command_w)
+void playmark_state::playmark_snd_command_w(offs_t offset, uint16_t data, uint16_t mem_mask)
 {
 	if (ACCESSING_BITS_0_7)
 	{
@@ -205,7 +205,7 @@ WRITE16_MEMBER(playmark_state::playmark_snd_command_w)
 	}
 }
 
-READ8_MEMBER(playmark_state::playmark_snd_command_r)
+uint8_t playmark_state::playmark_snd_command_r()
 {
 	int data = 0;
 
@@ -223,7 +223,7 @@ READ8_MEMBER(playmark_state::playmark_snd_command_r)
 	return data;
 }
 
-READ8_MEMBER(playmark_state::playmark_snd_flag_r)
+uint8_t playmark_state::playmark_snd_flag_r()
 {
 	if (m_snd_flag)
 	{
@@ -235,7 +235,7 @@ READ8_MEMBER(playmark_state::playmark_snd_flag_r)
 }
 
 
-WRITE8_MEMBER(playmark_state::playmark_oki_banking_w)
+void playmark_state::playmark_oki_banking_w(uint8_t data)
 {
 	logerror("%s Writing %02x to PortA  (OKI bank select)\n",machine().describe_context(),data);
 
@@ -244,12 +244,12 @@ WRITE8_MEMBER(playmark_state::playmark_oki_banking_w)
 	m_okibank->set_entry(bank & (m_oki_numbanks - 1));
 }
 
-WRITE8_MEMBER(playmark_state::playmark_oki_w)
+void playmark_state::playmark_oki_w(uint8_t data)
 {
 	m_oki_command = data;
 }
 
-WRITE8_MEMBER(playmark_state::playmark_snd_control_w)
+void playmark_state::playmark_snd_control_w(uint8_t data)
 {
 	/*  This port controls communications to and from the 68K and the OKI device.
 
@@ -272,7 +272,7 @@ WRITE8_MEMBER(playmark_state::playmark_snd_control_w)
 	}
 }
 
-WRITE8_MEMBER(playmark_state::hrdtimes_snd_control_w)
+void playmark_state::hrdtimes_snd_control_w(uint8_t data)
 {
 	/*  This port controls communications to and from the 68K and the OKI device. See playmark_snd_control_w above. OKI banking is also handled here. */
 
@@ -1033,7 +1033,7 @@ void playmark_state::configure_oki_banks()
 	}
 }
 
-MACHINE_START_MEMBER(playmark_state,playmark)
+void playmark_state::machine_start()
 {
 	save_item(NAME(m_bgscrollx));
 	save_item(NAME(m_bgscrolly));
@@ -1054,7 +1054,7 @@ MACHINE_START_MEMBER(playmark_state,playmark)
 
 
 
-MACHINE_RESET_MEMBER(playmark_state,playmark)
+void playmark_state::machine_reset()
 {
 	m_bgscrollx = 0;
 	m_bgscrolly = 0;
@@ -1085,9 +1085,6 @@ void playmark_state::bigtwin(machine_config &config)
 	m_audiocpu->read_c().set(FUNC(playmark_state::playmark_snd_flag_r));
 	m_audiocpu->write_c().set(FUNC(playmark_state::playmark_snd_control_w));
 
-	MCFG_MACHINE_START_OVERRIDE(playmark_state,playmark)
-	MCFG_MACHINE_RESET_OVERRIDE(playmark_state,playmark)
-
 	/* video hardware */
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
 	screen.set_refresh_hz(58);
@@ -1124,9 +1121,6 @@ void playmark_state::bigtwinb(machine_config &config)
 	m_audiocpu->read_c().set(FUNC(playmark_state::playmark_snd_flag_r));
 	m_audiocpu->write_c().set(FUNC(playmark_state::playmark_snd_control_w));
 
-	MCFG_MACHINE_START_OVERRIDE(playmark_state,playmark)
-	MCFG_MACHINE_RESET_OVERRIDE(playmark_state,playmark)
-
 	/* video hardware */
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
 	screen.set_refresh_hz(58);
@@ -1166,9 +1160,6 @@ void playmark_state::wbeachvl(machine_config &config)
 
 	EEPROM_93C46_16BIT(config, "eeprom").default_value(0);
 
-	MCFG_MACHINE_START_OVERRIDE(playmark_state,playmark)
-	MCFG_MACHINE_RESET_OVERRIDE(playmark_state,playmark)
-
 	/* video hardware */
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
 	screen.set_refresh_hz(58);
@@ -1205,9 +1196,6 @@ void playmark_state::excelsr(machine_config &config)
 	m_audiocpu->read_c().set(FUNC(playmark_state::playmark_snd_flag_r));
 	m_audiocpu->write_c().set(FUNC(playmark_state::playmark_snd_control_w));
 
-	MCFG_MACHINE_START_OVERRIDE(playmark_state,playmark)
-	MCFG_MACHINE_RESET_OVERRIDE(playmark_state,playmark)
-
 	/* video hardware */
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
 	screen.set_refresh_hz(58);
@@ -1245,9 +1233,6 @@ void playmark_state::hrdtimes(machine_config &config)
 	m_audiocpu->write_c().set(FUNC(playmark_state::hrdtimes_snd_control_w));
 	m_audiocpu->set_disable();       /* Internal code is not dumped yet */
 
-	MCFG_MACHINE_START_OVERRIDE(playmark_state,playmark)
-	MCFG_MACHINE_RESET_OVERRIDE(playmark_state,playmark)
-
 	/* video hardware */
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
 	screen.set_refresh_hz(58);
@@ -1286,9 +1271,6 @@ void playmark_state::hotmind(machine_config &config)
 
 	EEPROM_93C46_16BIT(config, "eeprom").default_value(0);
 
-	MCFG_MACHINE_START_OVERRIDE(playmark_state,playmark)
-	MCFG_MACHINE_RESET_OVERRIDE(playmark_state,playmark)
-
 	/* video hardware */
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
 	screen.set_refresh_hz(58);
@@ -1330,9 +1312,6 @@ void playmark_state::luckboomh(machine_config &config)
 
 	NVRAM(config, "nvram", nvram_device::DEFAULT_ALL_0);
 
-	MCFG_MACHINE_START_OVERRIDE(playmark_state,playmark)
-	MCFG_MACHINE_RESET_OVERRIDE(playmark_state,playmark)
-
 	/* video hardware */
 	screen_device &screen(SCREEN(config, "screen", SCREEN_TYPE_RASTER));
 	screen.set_refresh_hz(58);
