@@ -76,24 +76,6 @@ uint8_t psion_state::port2_r()
 	return m_pack1->data_r() | m_pack2->data_r();
 }
 
-void psion_state::tcsr_w(uint8_t data)
-{
-	m_tcsr_value = data;
-	m_maincpu->tcsr_w(data);
-}
-
-uint8_t psion_state::tcsr_r()
-{
-	if (!machine().side_effects_disabled())
-		m_maincpu->tcsr_w(m_tcsr_value);
-	return m_maincpu->tcsr_r();
-}
-
-uint8_t psion_state::rcp5c_r()
-{
-	return (m_maincpu->rcr_r()&0x7f) | (m_stby_pwr<<7);
-}
-
 uint8_t psion_state::port5_r()
 {
 	/*
@@ -188,7 +170,7 @@ void psion_state::io_rw(uint16_t offset)
 	}
 }
 
-WRITE8_MEMBER( psion_state::io_w )
+void psion_state::io_w(offs_t offset, uint8_t data)
 {
 	switch (offset & 0x0ffc0)
 	{
@@ -200,7 +182,7 @@ WRITE8_MEMBER( psion_state::io_w )
 	}
 }
 
-READ8_MEMBER( psion_state::io_r )
+uint8_t psion_state::io_r(offs_t offset)
 {
 	switch (offset & 0xffc0)
 	{
@@ -221,19 +203,19 @@ INPUT_CHANGED_MEMBER(psion_state::psion_on)
 		m_maincpu->reset();
 }
 
-READ8_MEMBER( psion1_state::reset_kb_counter_r )
+uint8_t psion1_state::reset_kb_counter_r()
 {
 	m_kb_counter = 0;
 	return 0;
 }
 
-READ8_MEMBER( psion1_state::inc_kb_counter_r )
+uint8_t psion1_state::inc_kb_counter_r()
 {
 	m_kb_counter++;
 	return 0;
 }
 
-READ8_MEMBER( psion1_state::switchoff_r )
+uint8_t psion1_state::switchoff_r()
 {
 	if (!m_stby_pwr)
 	{
@@ -247,8 +229,6 @@ void psion_state::psion_int_reg(address_map &map)
 {
 	// FIXME: this should all be made internal to the CPU device
 	map(0x0000, 0x001f).m(m_maincpu, FUNC(hd6301x_cpu_device::hd6301x_io));
-	map(0x0008, 0x0008).rw(FUNC(psion_state::tcsr_r), FUNC(psion_state::tcsr_w));
-	map(0x0014, 0x0014).r(FUNC(psion_state::rcp5c_r));
 }
 
 void psion1_state::psion1_mem(address_map &map)
@@ -496,7 +476,6 @@ void psion_state::machine_start()
 
 	save_item(NAME(m_kb_counter));
 	save_item(NAME(m_enable_nmi));
-	save_item(NAME(m_tcsr_value));
 	save_item(NAME(m_stby_pwr));
 	save_item(NAME(m_pulse));
 	save_item(NAME(m_rom_bank));
@@ -514,6 +493,10 @@ void psion_state::machine_reset()
 
 	if (m_rom_bank_count || m_ram_bank_count)
 		update_banks();
+
+	// enable warm boot
+	u8 mcu_rp5cr = m_maincpu->space(AS_PROGRAM).read_byte(0x14);
+	m_maincpu->space(AS_PROGRAM).write_byte(0x14, (mcu_rp5cr & 0x7f) | (m_stby_pwr << 7));
 }
 
 void psion1_state::machine_reset()
@@ -535,14 +518,14 @@ HD44780_PIXEL_UPDATE(psion_state::lz_pixel_update)
 		};
 
 		uint8_t char_pos = psion_display_layout[line*40 + pos];
-		bitmap.pix16((char_pos / 20) * 9 + y, (char_pos % 20) * 6 + x) = state;
+		bitmap.pix((char_pos / 20) * 9 + y, (char_pos % 20) * 6 + x) = state;
 	}
 }
 
 HD44780_PIXEL_UPDATE(psion1_state::psion1_pixel_update)
 {
 	if (pos < 8 && line < 2)
-		bitmap.pix16(y, (line * 8 + pos) * 6 + x) = state;
+		bitmap.pix(y, (line * 8 + pos) * 6 + x) = state;
 }
 
 void psion_state::psion_palette(palette_device &palette) const
