@@ -187,17 +187,17 @@ Demo tape contents:
 
 /* Read/Write Handlers */
 
-WRITE8_MEMBER( tmc1800_state::keylatch_w )
+void tmc1800_state::keylatch_w(uint8_t data)
 {
 	m_keylatch = data;
 }
 
-WRITE8_MEMBER( osc1000b_state::keylatch_w )
+void osc1000b_state::keylatch_w(uint8_t data)
 {
 	m_keylatch = data;
 }
 
-WRITE8_MEMBER( tmc2000_state::keylatch_w )
+void tmc2000_state::keylatch_w(uint8_t data)
 {
 	/*
 
@@ -217,7 +217,7 @@ WRITE8_MEMBER( tmc2000_state::keylatch_w )
 	m_keylatch = data & 0x3f;
 }
 
-WRITE8_MEMBER( nano_state::keylatch_w )
+void nano_state::keylatch_w(uint8_t data)
 {
 	/*
 
@@ -280,7 +280,7 @@ void tmc2000_state::bankswitch()
 	}
 }
 
-WRITE8_MEMBER( tmc2000_state::bankswitch_w )
+void tmc2000_state::bankswitch_w(uint8_t data)
 {
 	m_roc = 0;
 	m_rac = BIT(data, 0);
@@ -289,7 +289,7 @@ WRITE8_MEMBER( tmc2000_state::bankswitch_w )
 	m_cti->tone_latch_w(data);
 }
 
-WRITE8_MEMBER( nano_state::bankswitch_w )
+void nano_state::bankswitch_w(uint8_t data)
 {
 	/* enable RAM */
 	address_space &program = m_maincpu->space(AS_PROGRAM);
@@ -300,7 +300,7 @@ WRITE8_MEMBER( nano_state::bankswitch_w )
 	m_cti->tone_latch_w(data);
 }
 
-READ8_MEMBER( tmc1800_state::dispon_r )
+uint8_t tmc1800_state::dispon_r()
 {
 	m_vdc->disp_on_w(1);
 	m_vdc->disp_on_w(0);
@@ -308,7 +308,7 @@ READ8_MEMBER( tmc1800_state::dispon_r )
 	return 0xff;
 }
 
-WRITE8_MEMBER( tmc1800_state::dispoff_w )
+void tmc1800_state::dispoff_w(uint8_t data)
 {
 	m_vdc->disp_off_w(1);
 	m_vdc->disp_off_w(0);
@@ -624,7 +624,7 @@ WRITE_LINE_MEMBER( tmc2000_state::q_w )
 	m_cassette->output(state ? 1.0 : -1.0);
 }
 
-WRITE8_MEMBER( tmc2000_state::dma_w )
+void tmc2000_state::dma_w(offs_t offset, uint8_t data)
 {
 	m_color = ~(m_colorram[offset & 0x1ff]) & 0x07;
 
@@ -703,8 +703,6 @@ void tmc2000_state::machine_start()
 {
 	m_led.resolve();
 
-	m_colorram.allocate(TMC2000_COLORRAM_SIZE);
-
 	// randomize color RAM contents
 	for (uint16_t addr = 0; addr < TMC2000_COLORRAM_SIZE; addr++)
 	{
