@@ -70,13 +70,13 @@ private:
 
 	IRQ_CALLBACK_MEMBER(jack_sh_irq_ack);
 	void joinem_control_w(uint8_t data);
-	DECLARE_WRITE8_MEMBER(joinem_scroll_w);
-	DECLARE_READ8_MEMBER(striv_question_r);
-	DECLARE_WRITE8_MEMBER(jack_videoram_w);
-	DECLARE_WRITE8_MEMBER(jack_colorram_w);
-	DECLARE_READ8_MEMBER(jack_flipscreen_r);
-	DECLARE_WRITE8_MEMBER(jack_flipscreen_w);
-	DECLARE_READ8_MEMBER(timer_r);
+	void joinem_scroll_w(offs_t offset, uint8_t data);
+	uint8_t striv_question_r(offs_t offset);
+	void jack_videoram_w(offs_t offset, uint8_t data);
+	void jack_colorram_w(offs_t offset, uint8_t data);
+	uint8_t jack_flipscreen_r(offs_t offset);
+	void jack_flipscreen_w(offs_t offset, uint8_t data);
+	uint8_t timer_r();
 
 	TILE_GET_INFO_MEMBER(get_bg_tile_info);
 	TILEMAP_MAPPER_MEMBER(tilemap_scan_cols_flipy);
