@@ -43,6 +43,10 @@ public:
 
 	DECLARE_INPUT_CHANGED_MEMBER(coin_inserted);
 
+protected:
+	virtual void machine_start() override { m_main_sense_state = 0; }
+	virtual void video_start() override;
+
 private:
 	required_device<s2650_device> m_maincpu;
 	optional_device<s2650_device> m_audiocpu;
@@ -77,7 +81,6 @@ private:
 	void meadows_videoram_w(offs_t offset, uint8_t data);
 	void meadows_spriteram_w(offs_t offset, uint8_t data);
 	TILE_GET_INFO_MEMBER(get_tile_info);
-	virtual void video_start() override;
 	uint32_t screen_update_meadows(screen_device &screen, bitmap_ind16 &bitmap, const rectangle &cliprect);
 	DECLARE_WRITE_LINE_MEMBER(meadows_vblank_irq);
 	DECLARE_WRITE_LINE_MEMBER(minferno_vblank_irq);
