@@ -18,10 +18,10 @@ class mathbox_device : public device_t
 public:
 	mathbox_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
-	DECLARE_WRITE8_MEMBER( go_w );
-	DECLARE_READ8_MEMBER( status_r );
-	DECLARE_READ8_MEMBER( lo_r );
-	DECLARE_READ8_MEMBER( hi_r );
+	void go_w(offs_t offset, uint8_t data);
+	uint8_t status_r();
+	uint8_t lo_r();
+	uint8_t hi_r();
 
 protected:
 	// device-level overrides
