@@ -4,10 +4,10 @@
 #include "emu.h"
 #include "wpc_lamp.h"
 
-const device_type WPC_LAMP = &device_creator<wpc_lamp_device>;
+DEFINE_DEVICE_TYPE(WPC_LAMP, wpc_lamp_device, "wpc_lamp", "Williams Pinball Controller Lamp Control")
 
 wpc_lamp_device::wpc_lamp_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock) :
-	device_t(mconfig, WPC_LAMP, "Williams Pinball Controller Lamp Control", tag, owner, clock, "wpc_lamp", __FILE__)
+	device_t(mconfig, WPC_LAMP, tag, owner, clock)
 {
 	names = nullptr;
 }
@@ -30,13 +30,13 @@ void wpc_lamp_device::update()
 					state[(j<<3)|i] |= 0x80;
 }
 
-WRITE8_MEMBER(wpc_lamp_device::row_w)
+void wpc_lamp_device::row_w(uint8_t data)
 {
 	row = data;
 	update();
 }
 
-WRITE8_MEMBER(wpc_lamp_device::col_w)
+void wpc_lamp_device::col_w(uint8_t data)
 {
 	col = data;
 	update();
