@@ -281,14 +281,14 @@ WRITE_LINE_MEMBER(bfm_adder2_device::adder2_vbl_w)
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER( bfm_adder2_device::screen_ram_r )
+uint8_t bfm_adder2_device::screen_ram_r(offs_t offset)
 {
 	return m_screen_page_reg & SL_ACCESS ? m_screen_ram[1][offset]:m_screen_ram[0][offset];
 }
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::screen_ram_w )
+void bfm_adder2_device::screen_ram_w(offs_t offset, uint8_t data)
 {
 	int dirty_off = (offset>>7)*50 + ((offset & 0x7F)>>1);
 
@@ -320,28 +320,28 @@ WRITE8_MEMBER( bfm_adder2_device::screen_ram_w )
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER( bfm_adder2_device::normal_ram_r )
+uint8_t bfm_adder2_device::normal_ram_r(offs_t offset)
 {
 	return m_adder_ram[offset];
 }
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::normal_ram_w )
+void bfm_adder2_device::normal_ram_w(offs_t offset, uint8_t data)
 {
 	m_adder_ram[offset] = data;
 }
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::adder2_rom_page_w )
+void bfm_adder2_device::adder2_rom_page_w(uint8_t data)
 {
 	membank("bank2")->set_entry(data&0x03);
 }
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::adder2_c001_w )
+void bfm_adder2_device::adder2_c001_w(uint8_t data)
 {
 	logerror("c101 = %02X\n",data);
 
@@ -350,14 +350,14 @@ WRITE8_MEMBER( bfm_adder2_device::adder2_c001_w )
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::adder2_screen_page_w )
+void bfm_adder2_device::adder2_screen_page_w(uint8_t data)
 {
 	m_screen_page_reg = data;
 }
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER( bfm_adder2_device::adder2_vbl_ctrl_r )
+uint8_t bfm_adder2_device::adder2_vbl_ctrl_r()
 {
 	m_vbl_triggered = false;    // clear VBL start IRQ
 
@@ -366,14 +366,14 @@ READ8_MEMBER( bfm_adder2_device::adder2_vbl_ctrl_r )
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::adder2_vbl_ctrl_w )
+void bfm_adder2_device::adder2_vbl_ctrl_w(uint8_t data)
 {
 	m_c101 = data;
 }
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER( bfm_adder2_device::adder2_uart_ctrl_r )
+uint8_t bfm_adder2_device::adder2_uart_ctrl_r()
 {
 	int status = 0;
 
@@ -385,7 +385,7 @@ READ8_MEMBER( bfm_adder2_device::adder2_uart_ctrl_r )
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::adder2_uart_ctrl_w )
+void bfm_adder2_device::adder2_uart_ctrl_w(uint8_t data)
 {
 	m_data_from_sc2 = false;    // data available for adder from sc2
 	m_sc2data       = 0;        // data
@@ -397,7 +397,7 @@ WRITE8_MEMBER( bfm_adder2_device::adder2_uart_ctrl_w )
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER( bfm_adder2_device::adder2_uart_rx_r )
+uint8_t bfm_adder2_device::adder2_uart_rx_r()
 {
 	int data = m_sc2data;
 	m_data_from_sc2 = false;    // clr flag, data from scorpion2 board available
@@ -409,7 +409,7 @@ READ8_MEMBER( bfm_adder2_device::adder2_uart_rx_r )
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER( bfm_adder2_device::adder2_uart_tx_w )
+void bfm_adder2_device::adder2_uart_tx_w(uint8_t data)
 {
 	m_data_to_sc2 = true;       // set flag, data from adder available
 	m_adder2_data = data;       // store data
@@ -419,7 +419,7 @@ WRITE8_MEMBER( bfm_adder2_device::adder2_uart_tx_w )
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER( bfm_adder2_device::adder2_irq_r )
+uint8_t bfm_adder2_device::adder2_irq_r()
 {
 	int status = 0;
 
@@ -432,7 +432,7 @@ READ8_MEMBER( bfm_adder2_device::adder2_irq_r )
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER(bfm_adder2_device::vid_uart_tx_w)
+void bfm_adder2_device::vid_uart_tx_w(uint8_t data)
 {
 	m_data_from_sc2  = true;    // set flag, data from scorpion2 board available
 	m_sc2data        = data;    // store data
@@ -446,13 +446,13 @@ WRITE8_MEMBER(bfm_adder2_device::vid_uart_tx_w)
 
 ///////////////////////////////////////////////////////////////////////////
 
-WRITE8_MEMBER(bfm_adder2_device::vid_uart_ctrl_w)
+void bfm_adder2_device::vid_uart_ctrl_w(uint8_t data)
 {
 }
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER(bfm_adder2_device::vid_uart_rx_r)
+uint8_t bfm_adder2_device::vid_uart_rx_r()
 {
 	uint8_t data = m_adder2_data;
 	m_data_to_sc2 = false;   // clr flag, data from adder available
@@ -464,7 +464,7 @@ READ8_MEMBER(bfm_adder2_device::vid_uart_rx_r)
 
 ///////////////////////////////////////////////////////////////////////////
 
-READ8_MEMBER(bfm_adder2_device::vid_uart_ctrl_r)
+uint8_t bfm_adder2_device::vid_uart_ctrl_r()
 {
 	int status = 0;
 
