@@ -20,8 +20,7 @@ class pm_module : public osd_module, public midi_module
 {
 public:
 
-	pm_module()
-	: osd_module(OSD_MIDI_PROVIDER, "pm"), midi_module()
+	pm_module() : osd_module(OSD_MIDI_PROVIDER, "pm"), midi_module()
 	{
 	}
 	virtual ~pm_module() { }
