@@ -38,6 +38,7 @@ using util::BIT;
 #include "cpu/cosmac/cosdasm.h"
 #include "cpu/cp1610/1610dasm.h"
 #include "cpu/cr16b/cr16bdasm.h"
+#include "cpu/cr16c/cr16cdasm.h"
 #include "cpu/cubeqcpu/cubedasm.h"
 #include "cpu/dsp16/dsp16dis.h"
 #include "cpu/dsp32/dsp32dis.h"
@@ -73,9 +74,12 @@ using util::BIT;
 #include "cpu/ie15/ie15dasm.h"
 #include "cpu/jaguar/jagdasm.h"
 #include "cpu/ks0164/ks0164d.h"
+#include "cpu/lc57/lc57d.h"
+#include "cpu/lc58/lc58d.h"
 #include "cpu/lc8670/lc8670dsm.h"
 #include "cpu/lh5801/5801dasm.h"
 #include "cpu/lr35902/lr35902d.h"
+#include "cpu/m32c/m32cdasm.h"
 #include "cpu/m37710/m7700ds.h"
 #include "cpu/m6502/m4510d.h"
 #include "cpu/m6502/m6502d.h"
@@ -109,6 +113,7 @@ using util::BIT;
 #include "cpu/mips/mips1dsm.h"
 #include "cpu/mn1880/mn1880d.h"
 #include "cpu/mn10200/mn102dis.h"
+#include "cpu/msm65x2/msm65x2d.h"
 #include "cpu/nanoprocessor/nanoprocessor_dasm.h"
 #include "cpu/nec/necdasm.h"
 #include "cpu/ns32000/ns32000dasm.h"
@@ -116,7 +121,6 @@ using util::BIT;
 #include "cpu/pace/pacedasm.h"
 #include "cpu/patinhofeio/patinho_feio_dasm.h"
 #include "cpu/pdp1/pdp1dasm.h"
-#include "cpu/pdp1/tx0dasm.h"
 #include "cpu/pdp8/pdp8dasm.h"
 #include "cpu/pic16/pic16d.h"
 #include "cpu/pic1670/pic1670d.h"
@@ -163,6 +167,7 @@ using util::BIT;
 #include "cpu/tms7000/7000dasm.h"
 #include "cpu/tms9900/9900dasm.h"
 #include "cpu/tms9900/tms99com.h"
+#include "cpu/tx0/tx0dasm.h"
 #include "cpu/ucom4/ucom4d.h"
 #include "cpu/unsp/unspdasm.h"
 #include "cpu/upd177x/upd177xd.h"
@@ -188,11 +193,19 @@ using util::BIT;
 #include "eminline.h"
 
 #include <algorithm>
+#include <cctype>
+#include <cstdio>
+#include <cstdlib>
 #include <cstring>
 #include <iostream>
 #include <stdexcept>
 
-#include <cctype>
+#ifdef _WIN32
+#include <fcntl.h>
+#include <io.h>
+#include <stdio.h>
+#endif
+
 
 using u8 = util::u8;
 using u16 = util::u16;
@@ -375,6 +388,7 @@ static const dasm_table_entry dasm_table[] =
 	{ "cp1610",          be, -1, []() -> util::disasm_interface * { return new cp1610_disassembler; } },
 	{ "cr16a",           le,  0, []() -> util::disasm_interface * { return new cr16a_disassembler; } },
 	{ "cr16b",           le,  0, []() -> util::disasm_interface * { return new cr16b_disassembler; } },
+	{ "cr16c",           le,  0, []() -> util::disasm_interface * { return new cr16c_disassembler; } },
 	{ "cquestlin",       be, -3, []() -> util::disasm_interface * { return new cquestlin_disassembler; } },
 	{ "cquestrot",       be, -3, []() -> util::disasm_interface * { return new cquestrot_disassembler; } },
 	{ "cquestsnd",       be, -3, []() -> util::disasm_interface * { return new cquestsnd_disassembler; } },
@@ -434,10 +448,13 @@ static const dasm_table_entry dasm_table[] =
 	{ "jaguargpu",       be,  0, []() -> util::disasm_interface * { return new jaguar_disassembler(jaguar_disassembler::variant::GPU); } },
 	{ "konami",          be,  0, []() -> util::disasm_interface * { return new konami_disassembler; } },
 	{ "ks0164",          be,  0, []() -> util::disasm_interface * { return new ks0164_disassembler; } },
+	{ "lc57",            be,  0, []() -> util::disasm_interface * { return new lc57_disassembler; } },
+	{ "lc58",            be, -1, []() -> util::disasm_interface * { return new lc58_disassembler; } },
 	{ "lc8670",          be,  0, []() -> util::disasm_interface * { return new lc8670_disassembler; } },
 	{ "lh5801",          le,  0, []() -> util::disasm_interface * { return new lh5801_disassembler; } },
 	{ "lr35902",         le,  0, []() -> util::disasm_interface * { return new lr35902_disassembler; } },
 	{ "m146805",         be,  0, []() -> util::disasm_interface * { return new m146805_disassembler; } },
+	{ "m32c",            le,  0, []() -> util::disasm_interface * { return new m32c_disassembler; } },
 	{ "m37710",          le,  0, []() -> util::disasm_interface * { return new m7700_disassembler(&m7700_unidasm); } },
 	{ "m4510",           le,  0, []() -> util::disasm_interface * { return new m4510_disassembler; } },
 	{ "m58846",          le, -1, []() -> util::disasm_interface * { return new melps4_disassembler; } },
@@ -476,6 +493,7 @@ static const dasm_table_entry dasm_table[] =
 	{ "mn10200",         le,  0, []() -> util::disasm_interface * { return new mn10200_disassembler; } },
 	{ "mn1870",          be,  0, []() -> util::disasm_interface * { return new mn1870_disassembler; } },
 	{ "mn1880",          be,  0, []() -> util::disasm_interface * { return new mn1880_disassembler; } },
+	{ "msm65x2",         le,  0, []() -> util::disasm_interface * { return new msm65x2_disassembler; } },
 	{ "nanoprocessor",   le,  0, []() -> util::disasm_interface * { return new hp_nanoprocessor_disassembler; } },
 	{ "nec",             le,  0, []() -> util::disasm_interface * { return new nec_disassembler(&nec_unidasm); } },
 	{ "ns32000",         le,  0, []() -> util::disasm_interface * { return new ns32000_disassembler; } },
@@ -1051,7 +1069,7 @@ static int parse_options(int argc, char *argv[], options *opts)
 		char *curarg = argv[arg];
 
 		// is it a switch?
-		if(curarg[0] == '-') {
+		if(curarg[0] == '-' && curarg[1] != '\0') {
 			if(pending_base || pending_arch || pending_mode || pending_skip || pending_count)
 				goto usage;
 
@@ -1077,11 +1095,9 @@ static int parse_options(int argc, char *argv[], options *opts)
 				opts->xchbytes = true;
 			else
 				goto usage;
-		}
 
+		} else if(pending_base) {
 		// base PC
-		else if(pending_base)
-		{
 			int result;
 			if(curarg[0] == '0' && curarg[1] == 'x')
 				result = sscanf(&curarg[2], "%x", &opts->basepc);
@@ -1092,30 +1108,26 @@ static int parse_options(int argc, char *argv[], options *opts)
 			if(result != 1)
 				goto usage;
 			pending_base = false;
-		}
 
-		// mode
-		else if(pending_mode)
-		{
+		} else if(pending_mode) {
+			// mode
 			if(sscanf(curarg, "%d", &opts->mode) != 1)
 				goto usage;
 			pending_mode = false;
-		}
 
-		// architecture
-		else if(pending_arch) {
-			int curarch;
-			for(curarch = 0; curarch < ARRAY_LENGTH(dasm_table); curarch++)
-				if(core_stricmp(curarg, dasm_table[curarch].name) == 0)
-					break;
-			if(curarch == ARRAY_LENGTH(dasm_table))
+		} else if(pending_arch) {
+			// architecture
+			auto const arch = std::find_if(
+					std::begin(dasm_table),
+					std::end(dasm_table),
+					[&curarg] (dasm_table_entry const &e) { return !core_stricmp(curarg, e.name); });
+			if (std::end(dasm_table) == arch)
 				goto usage;
-			opts->dasm = &dasm_table[curarch];
+			opts->dasm = &*arch;
 			pending_arch = false;
-		}
 
-		// skip bytes
-		else if(pending_skip) {
+		} else if(pending_skip) {
+			// skip bytes
 			int result;
 			if(curarg[0] == '0' && curarg[1] == 'x')
 				result = sscanf(&curarg[2], "%x", &opts->skip);
@@ -1124,22 +1136,21 @@ static int parse_options(int argc, char *argv[], options *opts)
 			if(result != 1)
 				goto usage;
 			pending_skip = false;
-		}
 
-		// size
-		else if(pending_count) {
+		} else if(pending_count) {
+			// size
 			if(sscanf(curarg, "%d", &opts->count) != 1)
 				goto usage;
 			pending_count = false;
-		}
 
-		// filename
-		else if(opts->filename == nullptr)
+		} else if(opts->filename == nullptr) {
+			// filename
 			opts->filename = curarg;
 
-		// fail
-		else
+		} else {
+			// fail
 			goto usage;
+		}
 	}
 
 	// if we have a dangling option, error
@@ -1149,6 +1160,7 @@ static int parse_options(int argc, char *argv[], options *opts)
 	// if no file or no architecture, fail
 	if(opts->filename == nullptr || opts->dasm == nullptr)
 		goto usage;
+
 	return 0;
 
 usage:
@@ -1160,8 +1172,7 @@ usage:
 	const int colwidth = 1 + std::strlen(std::max_element(std::begin(dasm_table), std::end(dasm_table), [](const dasm_table_entry &a, const dasm_table_entry &b) { return std::strlen(a.name) < std::strlen(b.name); })->name);
 	const int columns = std::max(1, 80 / colwidth);
 	const int numrows = (ARRAY_LENGTH(dasm_table) + columns - 1) / columns;
-	for(unsigned curarch = 0; curarch < numrows * columns; curarch++)
-	{
+	for(unsigned curarch = 0; curarch < numrows * columns; curarch++) {
 		const int row = curarch / columns;
 		const int col = curarch % columns;
 		const int index = col * numrows + row;
@@ -1182,13 +1193,43 @@ int main(int argc, char *argv[])
 		return 1;
 
 	// Load the file
-	void *data;
-	uint32_t length;
-	osd_file::error filerr = util::core_file::load(opts.filename, &data, length);
-	if(filerr != osd_file::error::NONE)
+	void *data = nullptr;
+	u32 length = 0;
+	if(std::strcmp(opts.filename, "-") != 0) {
+		osd_file::error filerr = util::core_file::load(opts.filename, &data, length);
+		if(filerr != osd_file::error::NONE) {
+			std::fprintf(stderr, "Error opening file '%s'\n", opts.filename);
+			return 1;
+		}
+	}
+	else
 	{
-		fprintf(stderr, "Error opening file '%s'\n", opts.filename);
-		return 1;
+#ifdef _WIN32
+		if (_setmode(_fileno(stdin), _O_BINARY) == -1) {
+#else
+		if (!std::freopen(nullptr, "rb", stdin)) {
+#endif
+			std::fprintf(stderr, "Error reopening stdin in binary mode\n");
+			return 1;
+		}
+		std::size_t allocated = 0x1000;
+		data = std::malloc(allocated);
+		while(!std::ferror(stdin) && !std::feof(stdin)) {
+			if(length == allocated) {
+				allocated <<= 1;
+				data = std::realloc(data, allocated);
+			}
+			if(!data) {
+				std::fprintf(stderr, "Error allocating buffer\n");
+				return 1;
+			}
+
+			length += std::fread((u8 *)data + length, 1, allocated - length, stdin);
+		}
+		if(!length || (std::ferror(stdin) && !std::feof(stdin))) {
+			std::fprintf(stderr, "Error reading from stdin\n");
+			return 1;
+		}
 	}
 
 	// Build the disasm object
